# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from equinix.services.metalv1.models.plan import Plan
from typing import Optional, Set
from typing_extensions import Self

class SelfServiceReservationItemResponse(BaseModel):
    """
    SelfServiceReservationItemResponse
    """ # noqa: E501
    amount: Optional[Union[StrictFloat, StrictInt]] = None
    href: Optional[StrictStr] = None
    id: Optional[StrictStr] = None
    metro_code: Optional[StrictStr] = None
    metro_id: Optional[StrictStr] = None
    metro_name: Optional[StrictStr] = None
    plan: Optional[Plan] = None
    plan_categories: Optional[List[StrictStr]] = None
    plan_id: Optional[StrictStr] = None
    plan_name: Optional[StrictStr] = None
    plan_slug: Optional[StrictStr] = None
    quantity: Optional[StrictInt] = None
    term: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["amount", "href", "id", "metro_code", "metro_id", "metro_name", "plan", "plan_categories", "plan_id", "plan_name", "plan_slug", "quantity", "term"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SelfServiceReservationItemResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of plan
        if self.plan:
            _dict['plan'] = self.plan.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SelfServiceReservationItemResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "amount": obj.get("amount"),
            "href": obj.get("href"),
            "id": obj.get("id"),
            "metro_code": obj.get("metro_code"),
            "metro_id": obj.get("metro_id"),
            "metro_name": obj.get("metro_name"),
            "plan": Plan.from_dict(obj["plan"]) if obj.get("plan") is not None else None,
            "plan_categories": obj.get("plan_categories"),
            "plan_id": obj.get("plan_id"),
            "plan_name": obj.get("plan_name"),
            "plan_slug": obj.get("plan_slug"),
            "quantity": obj.get("quantity"),
            "term": obj.get("term")
        })
        return _obj





# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class VrfIpReservationCreateInput(BaseModel):
    """
    VrfIpReservationCreateInput
    """ # noqa: E501
    cidr: StrictInt = Field(description="The size of the VRF IP Reservation's subnet. The following subnet sizes are supported: - IPv4: between 22 - 29 inclusive - IPv6: exactly 64 ")
    customdata: Optional[Dict[str, Any]] = None
    details: Optional[StrictStr] = None
    href: Optional[StrictStr] = None
    network: StrictStr = Field(description="The starting address for this VRF IP Reservation's subnet. Both IPv4 and IPv6 are supported.")
    tags: Optional[List[StrictStr]] = None
    type: StrictStr = Field(description="Must be set to 'vrf'")
    vrf_id: StrictStr = Field(description="The ID of the VRF in which this VRF IP Reservation is created. The VRF must have an existing IP Range that contains the requested subnet. This field may be aliased as just 'vrf'.")
    __properties: ClassVar[List[str]] = ["cidr", "customdata", "details", "href", "network", "tags", "type", "vrf_id"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of VrfIpReservationCreateInput from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of VrfIpReservationCreateInput from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "cidr": obj.get("cidr"),
            "customdata": obj.get("customdata"),
            "details": obj.get("details"),
            "href": obj.get("href"),
            "network": obj.get("network"),
            "tags": obj.get("tags"),
            "type": obj.get("type"),
            "vrf_id": obj.get("vrf_id")
        })
        return _obj





# coding: utf-8

"""
    Equinix Fabric API v4

    Equinix Fabric is an advanced software-defined interconnection solution that enables you to directly, securely and dynamically connect to distributed infrastructure and digital ecosystems on platform Equinix via a single port, Customers can use Fabric to connect to: </br> 1. Cloud Service Providers - Clouds, network and other service providers.  </br> 2. Enterprises - Other Equinix customers, vendors and partners.  </br> 3. Myself - Another customer instance deployed at Equinix. </br> </br> <b>Integrations (SDKs, Tools) links:</b> </br> <a href=\"https://deploy.equinix.com/labs/fabric-java\\\">Fabric Java SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/equinix-sdk-go\\\">Fabric Go SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/equinix-sdk-python\\\">Fabric Python SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/terraform-provider-equinix\\\">Equinix Terraform Provider</a> </br> <a href=\"https://deploy.equinix.com/labs/terraform-equinix-fabric\\\">Fabric Terraform Modules</a> </br> <a href=\"https://deploy.equinix.com/labs/pulumi-provider-equinix/\">Equinix Pulumi Provider</a> </br>

    The version of the OpenAPI document: 4.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.fabricv4.models.connection_side import ConnectionSide

class TestConnectionSide(unittest.TestCase):
    """ConnectionSide unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ConnectionSide:
        """Test ConnectionSide
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ConnectionSide`
        """
        model = ConnectionSide()
        if include_optional:
            return ConnectionSide(
                service_token = equinix.services.fabricv4.models.service_token.ServiceToken(
                    type = 'VC_TOKEN', 
                    href = '', 
                    expiry = 56, 
                    uuid = '', 
                    issuer_side = '', 
                    name = '', 
                    description = '', 
                    expiration_date_time = '2020-11-06T07:00Z', 
                    connection = equinix.services.fabricv4.models.service_token_connection.ServiceTokenConnection(
                        type = 'EVPL_VC', 
                        href = '', 
                        uuid = '', 
                        allow_remote_connection = True, 
                        allow_custom_bandwidth = True, 
                        bandwidth_limit = 0, 
                        supported_bandwidths = [
                            56
                            ], 
                        a_side = equinix.services.fabricv4.models.service_token_side.ServiceTokenSide(
                            access_point_selectors = [
                                equinix.services.fabricv4.models.access_point_selector.AccessPointSelector(
                                    hide_asset_info = True, 
                                    port = equinix.services.fabricv4.models.simplified_metadata_entity.SimplifiedMetadataEntity(
                                        href = '', 
                                        uuid = '', 
                                        cvp_id = 56, 
                                        bandwidth = 1.337, 
                                        port_name = '', 
                                        encapsulation_protocol_type = '', 
                                        account_name = '', 
                                        priority = '', 
                                        location = equinix.services.fabricv4.models.simplified_location.SimplifiedLocation(
                                            metro_href = 'https://api.equinix.com/fabric/v4/metros/AM', 
                                            region = 'AMER, APAC, EMEA', 
                                            metro_name = 'Amsterdam', 
                                            metro_code = 'AM', 
                                            ibx = 'AM1', ), ), 
                                    link_protocol = equinix.services.fabricv4.models.simplified_link_protocol.SimplifiedLinkProtocol(
                                        vlan_tag = 2, 
                                        vlan_s_tag = 2, 
                                        vlan_c_tag = 2, ), 
                                    virtual_device = equinix.services.fabricv4.models.simplified_virtual_device.SimplifiedVirtualDevice(
                                        href = '', 
                                        uuid = '', 
                                        name = '', 
                                        cluster = '', ), 
                                    interface = equinix.services.fabricv4.models.virtual_device_interface.VirtualDeviceInterface(
                                        id = 56, 
                                        uuid = '', ), 
                                    network = equinix.services.fabricv4.models.simplified_token_network.SimplifiedTokenNetwork(
                                        href = '', 
                                        uuid = '', 
                                        name = '', 
                                        scope = 'LOCAL', ), )
                                ], ), 
                        z_side = equinix.services.fabricv4.models.service_token_side.ServiceTokenSide(), ), 
                    state = 'ACTIVE', 
                    notifications = [
                        equinix.services.fabricv4.models.simplified_notification.SimplifiedNotification(
                            type = 'BANDWIDTH_ALERT', 
                            send_interval = '', 
                            emails = [
                                ''
                                ], 
                            registered_users = [
                                ''
                                ], )
                        ], 
                    account = equinix.services.fabricv4.models.simplified_account.SimplifiedAccount(
                        account_number = 56, 
                        account_name = '', 
                        org_id = 56, 
                        organization_name = '', 
                        global_org_id = '', 
                        global_organization_name = '', 
                        ucm_id = '', 
                        global_cust_id = '', 
                        reseller_account_number = 56, 
                        reseller_account_name = '', 
                        reseller_ucm_id = '', 
                        reseller_org_id = 56, ), 
                    changelog = equinix.services.fabricv4.models.changelog.Changelog(
                        created_by = 'johnsmith', 
                        created_by_full_name = 'John Smith', 
                        created_by_email = 'john.smith@example.com', 
                        created_date_time = '2020-11-06T07:00Z', 
                        updated_by = 'johnsmith', 
                        updated_by_full_name = 'John Smith', 
                        updated_by_email = 'john.smith@example.com', 
                        updated_date_time = '2020-11-06T07:00Z', 
                        deleted_by = 'johnsmith', 
                        deleted_by_full_name = 'John Smith', 
                        deleted_by_email = 'john.smith@example.com', 
                        deleted_date_time = '2020-11-06T07:00Z', ), 
                    project = equinix.services.fabricv4.models.project.Project(
                        project_id = '44f4c4f8-2f39-494e-838c-d8e640591be5', ), ),
                access_point = equinix.services.fabricv4.models.access_point.AccessPoint(
                    type = 'VD', 
                    account = equinix.services.fabricv4.models.simplified_account.SimplifiedAccount(
                        account_number = 56, 
                        account_name = '', 
                        org_id = 56, 
                        organization_name = '', 
                        global_org_id = '', 
                        global_organization_name = '', 
                        ucm_id = '', 
                        global_cust_id = '', 
                        reseller_account_number = 56, 
                        reseller_account_name = '', 
                        reseller_ucm_id = '', 
                        reseller_org_id = 56, ), 
                    location = equinix.services.fabricv4.models.simplified_location.SimplifiedLocation(
                        metro_href = 'https://api.equinix.com/fabric/v4/metros/AM', 
                        region = 'AMER, APAC, EMEA', 
                        metro_name = 'Amsterdam', 
                        metro_code = 'AM', 
                        ibx = 'AM1', ), 
                    port = equinix.services.fabricv4.models.simplified_port.SimplifiedPort(
                        href = '', 
                        id = 56, 
                        uuid = '', 
                        name = '', 
                        description = '', 
                        physical_ports_speed = 0, 
                        connections_count = 0, 
                        project = equinix.services.fabricv4.models.project.Project(
                            project_id = '44f4c4f8-2f39-494e-838c-d8e640591be5', ), 
                        state = 'PENDING', 
                        operation = equinix.services.fabricv4.models.port_operation.PortOperation(
                            operational_status = 'UP', 
                            connection_count = 56, 
                            evpl_vc_count = 56, 
                            fg_vc_count = 56, 
                            access_vc_count = 56, 
                            op_status_changed_at = '2020-11-06T07:00Z', ), 
                        service_type = 'EPL', 
                        bandwidth = 0, 
                        available_bandwidth = 0, 
                        used_bandwidth = 0, 
                        device = equinix.services.fabricv4.models.port_device.PortDevice(
                            name = '', 
                            redundancy = equinix.services.fabricv4.models.port_device_redundancy.PortDeviceRedundancy(
                                group = '', 
                                priority = 'PRIMARY', ), ), 
                        interface = equinix.services.fabricv4.models.port_interface.PortInterface(), 
                        tether = equinix.services.fabricv4.models.port_tether.PortTether(
                            cross_connect_id = '', 
                            cabinet_number = '', 
                            system_name = '', 
                            patch_panel = '', 
                            patch_panel_port_a = '', 
                            patch_panel_port_b = '', 
                            ibx = '', ), 
                        demarcation_point = equinix.services.fabricv4.models.port_demarcation_point.PortDemarcationPoint(
                            cabinet_unique_space_id = '', 
                            cage_unique_space_id = '', 
                            patch_panel = '', 
                            patch_panel_name = '', 
                            patch_panel_port_a = '', 
                            patch_panel_port_b = '', 
                            connector_type = '', 
                            ibx = '', ), 
                        redundancy = equinix.services.fabricv4.models.port_redundancy.PortRedundancy(
                            enabled = True, 
                            group = '', ), 
                        encapsulation = equinix.services.fabricv4.models.port_encapsulation.PortEncapsulation(
                            tag_protocol_id = '', ), 
                        lag_enabled = True, 
                        package = equinix.services.fabricv4.models.package.Package(
                            code = 'STANDARD', ), 
                        settings = equinix.services.fabricv4.models.port_settings.PortSettings(
                            buyout = True, 
                            view_port_permission = True, 
                            place_vc_order_permission = True, 
                            layer3_enabled = True, 
                            shared_port_type = True, 
                            shared_port_product = 'NETWORK_EDGE', 
                            package_type = 'STANDARD', ), 
                        physical_port_quantity = 56, 
                        additional_info = [
                            equinix.services.fabricv4.models.port_additional_info.PortAdditionalInfo(
                                key = '', 
                                value = '', )
                            ], 
                        physical_ports = [
                            equinix.services.fabricv4.models.physical_port.PhysicalPort(
                                href = '', 
                                id = 56, 
                                interface_speed = 0, 
                                interface_type = '', 
                                uuid = '', 
                                notifications = [
                                    equinix.services.fabricv4.models.port_notification.PortNotification(
                                        type = 'NOTIFICATION', 
                                        registered_users = [
                                            ''
                                            ], )
                                    ], 
                                order = equinix.services.fabricv4.models.port_order.PortOrder(
                                    purchase_order = equinix.services.fabricv4.models.port_order_purchase_order.PortOrder_purchaseOrder(
                                        number = '', 
                                        amount = '', 
                                        start_date = '', 
                                        end_date = '', 
                                        attachment_id = '', 
                                        selection_type = 'EXEMPTION', ), 
                                    order_id = '', 
                                    customer_reference_id = '', 
                                    order_number = '', 
                                    uuid = '', 
                                    signature = equinix.services.fabricv4.models.port_order_signature.PortOrder_signature(
                                        signatory = 'DELEGATE', 
                                        delegate = equinix.services.fabricv4.models.port_order_signature_delegate.PortOrder_signature_delegate(
                                            first_name = '', 
                                            last_name = '', 
                                            email = '', ), ), ), 
                                loas = [
                                    equinix.services.fabricv4.models.port_loa.PortLoa(
                                        uuid = '', 
                                        href = '', )
                                    ], )
                            ], ), 
                    profile = equinix.services.fabricv4.models.simplified_service_profile.SimplifiedServiceProfile(
                        href = '', 
                        name = 'Sample Service Profile', 
                        uuid = '', 
                        description = 'offering connectivity to my-network', 
                        tags = [
                            ''
                            ], 
                        visibility = 'PRIVATE', 
                        allowed_emails = [
                            ''
                            ], 
                        access_point_type_configs = [
                            equinix.services.fabricv4.models.service_profile_access_point_type.ServiceProfileAccessPointType()
                            ], 
                        custom_fields = [
                            equinix.services.fabricv4.models.custom_field.CustomField(
                                label = 'Account Number', 
                                description = 'Provide a valid account number', 
                                required = True, 
                                data_type = 'STRING', 
                                options = [
                                    ''
                                    ], 
                                capture_in_email = True, )
                            ], 
                        marketing_info = equinix.services.fabricv4.models.marketing_info.MarketingInfo(
                            logo = '', 
                            promotion = True, 
                            process_steps = [
                                equinix.services.fabricv4.models.process_step.ProcessStep(
                                    title = '', 
                                    sub_title = '', 
                                    description = '', )
                                ], ), 
                        ports = [
                            equinix.services.fabricv4.models.service_profile_access_point_colo.ServiceProfileAccessPointCOLO(
                                type = 'XF_PORT', 
                                uuid = '94662143-e21b-4098-bfcf-e9416f47eae1', 
                                seller_region = '', 
                                seller_region_description = '', 
                                cross_connect_id = '', )
                            ], 
                        virtual_devices = [
                            equinix.services.fabricv4.models.service_profile_access_point_vd.ServiceProfileAccessPointVD(
                                type = 'VD', 
                                uuid = '94662143-e21b-4098-bfcf-e9416f47eae1', 
                                interface_uuid = '94662143-e21b-4098-bfcf-e9416f47eae1', )
                            ], 
                        metros = [
                            equinix.services.fabricv4.models.service_metro.ServiceMetro(
                                name = '', 
                                vc_bandwidth_max = 56, 
                                ibxs = [
                                    ''
                                    ], 
                                in_trail = True, 
                                display_name = '', 
                                seller_regions = {
                                    'key' : ''
                                    }, )
                            ], 
                        self_profile = True, 
                        project_id = '', ), 
                    router = equinix.services.fabricv4.models.cloud_router.CloudRouter(
                        href = 'https://api.equinix.com/fabric/v4/routers/3c9b8e7a2-f3b1-4576-a4a9-1366a63df170', 
                        uuid = 'c9b8e7a2-f3b1-4576-a4a9-1366a63df170', 
                        name = 'test-fg-1', 
                        equinix_asn = 30000, 
                        connections_count = 0, 
                        marketplace_subscription = equinix.services.fabricv4.models.marketplace_subscription.marketplaceSubscription(
                            href = 'https://api.equinix.com/fabric/v4/marketplaceSubscriptions/20d32a80-0d61-4333-bc03-707b591ae2f5', 
                            uuid = '20d32a80-0d61-4333-bc03-707b591ae2f5', ), 
                        change_log = equinix.services.fabricv4.models.changelog.Changelog(
                            created_by = 'johnsmith', 
                            created_by_full_name = 'John Smith', 
                            created_by_email = 'john.smith@example.com', 
                            created_date_time = '2020-11-06T07:00Z', 
                            updated_by = 'johnsmith', 
                            updated_by_full_name = 'John Smith', 
                            updated_by_email = 'john.smith@example.com', 
                            updated_date_time = '2020-11-06T07:00Z', 
                            deleted_by = 'johnsmith', 
                            deleted_by_full_name = 'John Smith', 
                            deleted_by_email = 'john.smith@example.com', 
                            deleted_date_time = '2020-11-06T07:00Z', ), 
                        change = equinix.services.fabricv4.models.cloud_router_change.CloudRouterChange(
                            uuid = '', 
                            type = 'ROUTER_UPDATE', 
                            status = 'COMPLETED', 
                            created_date_time = '2020-11-06T07:00Z', 
                            updated_date_time = '2020-11-06T07:00Z', 
                            information = '', 
                            data = equinix.services.fabricv4.models.cloud_router_change_operation.CloudRouterChangeOperation(
                                op = 'replace', 
                                path = '', 
                                value = equinix.services.fabricv4.models.value.value(), ), ), ), 
                    link_protocol = equinix.services.fabricv4.models.simplified_link_protocol.SimplifiedLinkProtocol(
                        vlan_tag = 2, 
                        vlan_s_tag = 2, 
                        vlan_c_tag = 2, ), 
                    virtual_device = equinix.services.fabricv4.models.virtual_device.VirtualDevice(
                        href = '', 
                        uuid = '', 
                        name = '', ), 
                    interface = equinix.services.fabricv4.models.interface.Interface(
                        href = '', 
                        uuid = '', 
                        id = 56, 
                        project_id = '', ), 
                    network = equinix.services.fabricv4.models.simplified_network.SimplifiedNetwork(
                        href = 'https://api.equinix.com/fabric/v4/networks/92dc376a-a932-43aa-a6a2-c806dedbd784', 
                        uuid = '92dc376a-a932-43aa-a6a2-c806dedbd784', 
                        name = 'My EVPLAN Network', 
                        links = [
                            equinix.services.fabricv4.models.link.Link(
                                href = '', 
                                rel = '', 
                                method = '', 
                                content_type = '', 
                                authenticate = True, )
                            ], 
                        scope = 'REGIONAL', ), 
                    seller_region = '', 
                    peering_type = 'PRIVATE', 
                    authentication_key = '', 
                    provider_connection_id = '', 
                    virtual_network = equinix.services.fabricv4.models.virtual_network.VirtualNetwork(
                        href = '', 
                        uuid = '', ), 
                    interconnection = equinix.services.fabricv4.models.metal_interconnection.MetalInterconnection(
                        uuid = '', ), 
                    vpic_interface = equinix.services.fabricv4.models.vpic_interface.VpicInterface(
                        href = '', 
                        uuid = '', ), ),
                internet_access = equinix.services.fabricv4.models.internet_access.InternetAccess(
                    uuid = '', ),
                company_profile = equinix.services.fabricv4.models.connection_company_profile.ConnectionCompanyProfile(
                    id = 1, 
                    name = 'Company-1', 
                    global_org_id = '', ),
                invitation = equinix.services.fabricv4.models.connection_invitation.ConnectionInvitation(
                    email = 'test@equinix.com', 
                    message = 'Hello, Please accept my invitation', 
                    ctr_draft_order_id = '', ),
                additional_info = [
                    equinix.services.fabricv4.models.connection_side_additional_info.ConnectionSideAdditionalInfo(
                        key = '', 
                        value = '', )
                    ]
            )
        else:
            return ConnectionSide(
        )
        """

    def testConnectionSide(self):
        """Test ConnectionSide"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Equinix Fabric API v4

    Equinix Fabric is an advanced software-defined interconnection solution that enables you to directly, securely and dynamically connect to distributed infrastructure and digital ecosystems on platform Equinix via a single port, Customers can use Fabric to connect to: </br> 1. Cloud Service Providers - Clouds, network and other service providers.  </br> 2. Enterprises - Other Equinix customers, vendors and partners.  </br> 3. Myself - Another customer instance deployed at Equinix. </br> </br> <b>Integrations (SDKs, Tools) links:</b> </br> <a href=\"https://deploy.equinix.com/labs/fabric-java\\\">Fabric Java SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/equinix-sdk-go\\\">Fabric Go SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/equinix-sdk-python\\\">Fabric Python SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/terraform-provider-equinix\\\">Equinix Terraform Provider</a> </br> <a href=\"https://deploy.equinix.com/labs/terraform-equinix-fabric\\\">Fabric Terraform Modules</a> </br> <a href=\"https://deploy.equinix.com/labs/pulumi-provider-equinix/\">Equinix Pulumi Provider</a> </br>

    The version of the OpenAPI document: 4.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.fabricv4.models.access_point import AccessPoint

class TestAccessPoint(unittest.TestCase):
    """AccessPoint unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AccessPoint:
        """Test AccessPoint
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AccessPoint`
        """
        model = AccessPoint()
        if include_optional:
            return AccessPoint(
                type = 'VD',
                account = equinix.services.fabricv4.models.simplified_account.SimplifiedAccount(
                    account_number = 56, 
                    account_name = '', 
                    org_id = 56, 
                    organization_name = '', 
                    global_org_id = '', 
                    global_organization_name = '', 
                    ucm_id = '', 
                    global_cust_id = '', 
                    reseller_account_number = 56, 
                    reseller_account_name = '', 
                    reseller_ucm_id = '', 
                    reseller_org_id = 56, ),
                location = equinix.services.fabricv4.models.simplified_location.SimplifiedLocation(
                    metro_href = 'https://api.equinix.com/fabric/v4/metros/AM', 
                    region = 'AMER, APAC, EMEA', 
                    metro_name = 'Amsterdam', 
                    metro_code = 'AM', 
                    ibx = 'AM1', ),
                port = equinix.services.fabricv4.models.simplified_port.SimplifiedPort(
                    href = '', 
                    type = 'XF_PORT', 
                    id = 56, 
                    uuid = '', 
                    name = '', 
                    description = '', 
                    physical_ports_speed = 0, 
                    connections_count = 0, 
                    project = equinix.services.fabricv4.models.project.Project(
                        project_id = '44f4c4f8-2f39-494e-838c-d8e640591be5', ), 
                    state = 'PENDING', 
                    operation = equinix.services.fabricv4.models.port_operation.PortOperation(
                        operational_status = 'UP', 
                        connection_count = 56, 
                        evpl_vc_count = 56, 
                        fg_vc_count = 56, 
                        access_vc_count = 56, 
                        op_status_changed_at = '2020-11-06T07:00Z', ), 
                    account = equinix.services.fabricv4.models.simplified_account.SimplifiedAccount(
                        account_number = 56, 
                        account_name = '', 
                        org_id = 56, 
                        organization_name = '', 
                        global_org_id = '', 
                        global_organization_name = '', 
                        ucm_id = '', 
                        global_cust_id = '', 
                        reseller_account_number = 56, 
                        reseller_account_name = '', 
                        reseller_ucm_id = '', 
                        reseller_org_id = 56, ), 
                    service_type = 'EPL', 
                    bandwidth = 0, 
                    available_bandwidth = 0, 
                    used_bandwidth = 0, 
                    location = equinix.services.fabricv4.models.simplified_location.SimplifiedLocation(
                        metro_href = 'https://api.equinix.com/fabric/v4/metros/AM', 
                        region = 'AMER, APAC, EMEA', 
                        metro_name = 'Amsterdam', 
                        metro_code = 'AM', 
                        ibx = 'AM1', ), 
                    device = equinix.services.fabricv4.models.port_device.PortDevice(
                        name = '', 
                        redundancy = equinix.services.fabricv4.models.port_device_redundancy.PortDeviceRedundancy(
                            group = '', 
                            priority = 'PRIMARY', ), ), 
                    interface = equinix.services.fabricv4.models.port_interface.PortInterface(), 
                    tether = equinix.services.fabricv4.models.port_tether.PortTether(
                        cross_connect_id = '', 
                        cabinet_number = '', 
                        system_name = '', 
                        patch_panel = '', 
                        patch_panel_port_a = '', 
                        patch_panel_port_b = '', 
                        ibx = '', ), 
                    demarcation_point = equinix.services.fabricv4.models.port_demarcation_point.PortDemarcationPoint(
                        cabinet_unique_space_id = '', 
                        cage_unique_space_id = '', 
                        patch_panel = '', 
                        patch_panel_name = '', 
                        patch_panel_port_a = '', 
                        patch_panel_port_b = '', 
                        connector_type = '', 
                        ibx = '', ), 
                    redundancy = equinix.services.fabricv4.models.port_redundancy.PortRedundancy(
                        enabled = True, 
                        group = '', ), 
                    encapsulation = equinix.services.fabricv4.models.port_encapsulation.PortEncapsulation(
                        tag_protocol_id = '', ), 
                    lag_enabled = True, 
                    package = equinix.services.fabricv4.models.package.Package(
                        code = 'STANDARD', ), 
                    settings = equinix.services.fabricv4.models.port_settings.PortSettings(
                        buyout = True, 
                        view_port_permission = True, 
                        place_vc_order_permission = True, 
                        layer3_enabled = True, 
                        shared_port_type = True, 
                        shared_port_product = 'NETWORK_EDGE', 
                        package_type = 'STANDARD', ), 
                    physical_port_quantity = 56, 
                    additional_info = [
                        equinix.services.fabricv4.models.port_additional_info.PortAdditionalInfo(
                            key = '', 
                            value = '', )
                        ], 
                    physical_ports = [
                        equinix.services.fabricv4.models.physical_port.PhysicalPort(
                            href = '', 
                            id = 56, 
                            interface_speed = 0, 
                            interface_type = '', 
                            uuid = '', 
                            notifications = [
                                equinix.services.fabricv4.models.port_notification.PortNotification(
                                    type = 'NOTIFICATION', 
                                    registered_users = [
                                        ''
                                        ], )
                                ], 
                            order = equinix.services.fabricv4.models.port_order.PortOrder(
                                purchase_order = equinix.services.fabricv4.models.port_order_purchase_order.PortOrder_purchaseOrder(
                                    number = '', 
                                    amount = '', 
                                    start_date = '', 
                                    end_date = '', 
                                    attachment_id = '', 
                                    selection_type = 'EXEMPTION', ), 
                                order_id = '', 
                                customer_reference_id = '', 
                                order_number = '', 
                                uuid = '', 
                                signature = equinix.services.fabricv4.models.port_order_signature.PortOrder_signature(
                                    signatory = 'DELEGATE', 
                                    delegate = equinix.services.fabricv4.models.port_order_signature_delegate.PortOrder_signature_delegate(
                                        first_name = '', 
                                        last_name = '', 
                                        email = '', ), ), ), 
                            loas = [
                                equinix.services.fabricv4.models.port_loa.PortLoa(
                                    uuid = '', 
                                    href = '', )
                                ], )
                        ], ),
                profile = equinix.services.fabricv4.models.simplified_service_profile.SimplifiedServiceProfile(
                    href = '', 
                    type = 'L2_PROFILE', 
                    name = 'Sample Service Profile', 
                    uuid = '', 
                    description = 'offering connectivity to my-network', 
                    notifications = [
                        equinix.services.fabricv4.models.simplified_notification.SimplifiedNotification(
                            type = 'BANDWIDTH_ALERT', 
                            send_interval = '', 
                            emails = [
                                ''
                                ], 
                            registered_users = [
                                ''
                                ], )
                        ], 
                    tags = [
                        ''
                        ], 
                    visibility = 'PRIVATE', 
                    allowed_emails = [
                        ''
                        ], 
                    access_point_type_configs = [
                        equinix.services.fabricv4.models.service_profile_access_point_type.ServiceProfileAccessPointType()
                        ], 
                    custom_fields = [
                        equinix.services.fabricv4.models.custom_field.CustomField(
                            label = 'Account Number', 
                            description = 'Provide a valid account number', 
                            required = True, 
                            data_type = 'STRING', 
                            options = [
                                ''
                                ], 
                            capture_in_email = True, )
                        ], 
                    marketing_info = equinix.services.fabricv4.models.marketing_info.MarketingInfo(
                        logo = '', 
                        promotion = True, 
                        process_steps = [
                            equinix.services.fabricv4.models.process_step.ProcessStep(
                                title = '', 
                                sub_title = '', 
                                description = '', )
                            ], ), 
                    ports = [
                        equinix.services.fabricv4.models.service_profile_access_point_colo.ServiceProfileAccessPointCOLO(
                            type = 'XF_PORT', 
                            uuid = '94662143-e21b-4098-bfcf-e9416f47eae1', 
                            location = equinix.services.fabricv4.models.simplified_location.SimplifiedLocation(
                                metro_href = 'https://api.equinix.com/fabric/v4/metros/AM', 
                                region = 'AMER, APAC, EMEA', 
                                metro_name = 'Amsterdam', 
                                metro_code = 'AM', 
                                ibx = 'AM1', ), 
                            seller_region = '', 
                            seller_region_description = '', 
                            cross_connect_id = '', )
                        ], 
                    virtual_devices = [
                        equinix.services.fabricv4.models.service_profile_access_point_vd.ServiceProfileAccessPointVD(
                            type = 'VD', 
                            uuid = '94662143-e21b-4098-bfcf-e9416f47eae1', 
                            interface_uuid = '94662143-e21b-4098-bfcf-e9416f47eae1', )
                        ], 
                    metros = [
                        equinix.services.fabricv4.models.service_metro.ServiceMetro(
                            code = '', 
                            name = '', 
                            vc_bandwidth_max = 56, 
                            ibxs = [
                                ''
                                ], 
                            in_trail = True, 
                            display_name = '', 
                            seller_regions = {
                                'key' : ''
                                }, )
                        ], 
                    self_profile = True, 
                    project_id = '', ),
                router = equinix.services.fabricv4.models.cloud_router.CloudRouter(
                    href = 'https://api.equinix.com/fabric/v4/routers/3c9b8e7a2-f3b1-4576-a4a9-1366a63df170', 
                    uuid = 'c9b8e7a2-f3b1-4576-a4a9-1366a63df170', 
                    name = 'test-fg-1', 
                    state = 'PROVISIONED', 
                    equinix_asn = 30000, 
                    connections_count = 0, 
                    marketplace_subscription = equinix.services.fabricv4.models.marketplace_subscription.marketplaceSubscription(
                        href = 'https://api.equinix.com/fabric/v4/marketplaceSubscriptions/20d32a80-0d61-4333-bc03-707b591ae2f5', 
                        type = 'AWS_MARKETPLACE_SUBSCRIPTION', 
                        uuid = '20d32a80-0d61-4333-bc03-707b591ae2f5', ), 
                    change_log = equinix.services.fabricv4.models.changelog.Changelog(
                        created_by = 'johnsmith', 
                        created_by_full_name = 'John Smith', 
                        created_by_email = 'john.smith@example.com', 
                        created_date_time = '2020-11-06T07:00Z', 
                        updated_by = 'johnsmith', 
                        updated_by_full_name = 'John Smith', 
                        updated_by_email = 'john.smith@example.com', 
                        updated_date_time = '2020-11-06T07:00Z', 
                        deleted_by = 'johnsmith', 
                        deleted_by_full_name = 'John Smith', 
                        deleted_by_email = 'john.smith@example.com', 
                        deleted_date_time = '2020-11-06T07:00Z', ), 
                    change = equinix.services.fabricv4.models.cloud_router_change.CloudRouterChange(
                        uuid = '', 
                        type = 'ROUTER_UPDATE', 
                        status = 'COMPLETED', 
                        created_date_time = '2020-11-06T07:00Z', 
                        updated_date_time = '2020-11-06T07:00Z', 
                        information = '', 
                        data = equinix.services.fabricv4.models.cloud_router_change_operation.CloudRouterChangeOperation(
                            op = 'replace', 
                            path = '', 
                            value = equinix.services.fabricv4.models.value.value(), ), ), ),
                link_protocol = equinix.services.fabricv4.models.simplified_link_protocol.SimplifiedLinkProtocol(
                    type = 'UNTAGGED', 
                    vlan_tag = 2, 
                    vlan_s_tag = 2, 
                    vlan_c_tag = 2, ),
                virtual_device = equinix.services.fabricv4.models.virtual_device.VirtualDevice(
                    href = '', 
                    uuid = '', 
                    name = '', 
                    type = 'EDGE', 
                    account = equinix.services.fabricv4.models.simplified_account.SimplifiedAccount(
                        account_number = 56, 
                        account_name = '', 
                        org_id = 56, 
                        organization_name = '', 
                        global_org_id = '', 
                        global_organization_name = '', 
                        ucm_id = '', 
                        global_cust_id = '', 
                        reseller_account_number = 56, 
                        reseller_account_name = '', 
                        reseller_ucm_id = '', 
                        reseller_org_id = 56, ), ),
                interface = equinix.services.fabricv4.models.interface.Interface(
                    href = '', 
                    uuid = '', 
                    id = 56, 
                    type = 'CLOUD', 
                    project_id = '', ),
                network = equinix.services.fabricv4.models.simplified_network.SimplifiedNetwork(
                    href = 'https://api.equinix.com/fabric/v4/networks/92dc376a-a932-43aa-a6a2-c806dedbd784', 
                    uuid = '92dc376a-a932-43aa-a6a2-c806dedbd784', 
                    name = 'My EVPLAN Network', 
                    state = 'ACTIVE', 
                    account = equinix.services.fabricv4.models.simplified_account.SimplifiedAccount(
                        account_number = 56, 
                        account_name = '', 
                        org_id = 56, 
                        organization_name = '', 
                        global_org_id = '', 
                        global_organization_name = '', 
                        ucm_id = '', 
                        global_cust_id = '', 
                        reseller_account_number = 56, 
                        reseller_account_name = '', 
                        reseller_ucm_id = '', 
                        reseller_org_id = 56, ), 
                    change = equinix.services.fabricv4.models.simplified_network_change.SimplifiedNetworkChange(
                        href = 'https://api.equinix.com/fabric/v4/networks/2a4fb415-5a7f-436f-bae6-02f5e403deec/changes/4b17da68-3d6b-436d-9c8f-2105f3b950d9', 
                        uuid = '4b17da68-3d6b-436d-9c8f-2105f3b950d9', 
                        type = 'NETWORK_CREATION', ), 
                    operation = equinix.services.fabricv4.models.network_operation.NetworkOperation(
                        equinix_status = 'PROVISIONING', ), 
                    change_log = equinix.services.fabricv4.models.changelog.Changelog(
                        created_by = 'johnsmith', 
                        created_by_full_name = 'John Smith', 
                        created_by_email = 'john.smith@example.com', 
                        created_date_time = '2020-11-06T07:00Z', 
                        updated_by = 'johnsmith', 
                        updated_by_full_name = 'John Smith', 
                        updated_by_email = 'john.smith@example.com', 
                        updated_date_time = '2020-11-06T07:00Z', 
                        deleted_by = 'johnsmith', 
                        deleted_by_full_name = 'John Smith', 
                        deleted_by_email = 'john.smith@example.com', 
                        deleted_date_time = '2020-11-06T07:00Z', ), 
                    links = [
                        equinix.services.fabricv4.models.link.Link(
                            href = '', 
                            rel = '', 
                            method = '', 
                            content_type = '', 
                            authenticate = True, )
                        ], 
                    type = 'EVPLAN', 
                    scope = 'REGIONAL', 
                    location = equinix.services.fabricv4.models.simplified_location.SimplifiedLocation(
                        metro_href = 'https://api.equinix.com/fabric/v4/metros/AM', 
                        region = 'AMER, APAC, EMEA', 
                        metro_name = 'Amsterdam', 
                        metro_code = 'AM', 
                        ibx = 'AM1', ), ),
                seller_region = '',
                peering_type = 'PRIVATE',
                authentication_key = '',
                provider_connection_id = '',
                virtual_network = equinix.services.fabricv4.models.virtual_network.VirtualNetwork(
                    href = '', 
                    uuid = '', ),
                interconnection = equinix.services.fabricv4.models.metal_interconnection.MetalInterconnection(
                    uuid = '', ),
                vpic_interface = equinix.services.fabricv4.models.vpic_interface.VpicInterface(
                    href = '', 
                    uuid = '', )
            )
        else:
            return AccessPoint(
        )
        """

    def testAccessPoint(self):
        """Test AccessPoint"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.ssh_key_list import SSHKeyList

class TestSSHKeyList(unittest.TestCase):
    """SSHKeyList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SSHKeyList:
        """Test SSHKeyList
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SSHKeyList`
        """
        model = SSHKeyList()
        if include_optional:
            return SSHKeyList(
                href = '',
                ssh_keys = [
                    equinix.services.metalv1.models.ssh_key.SSHKey(
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        entity = equinix.services.metalv1.models.href.Href(
                            href = '', ), 
                        fingerprint = '', 
                        href = '', 
                        id = '', 
                        key = '', 
                        label = '', 
                        tags = [
                            ''
                            ], 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ]
            )
        else:
            return SSHKeyList(
        )
        """

    def testSSHKeyList(self):
        """Test SSHKeyList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.api.support_request_api import SupportRequestApi


class TestSupportRequestApi(unittest.TestCase):
    """SupportRequestApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SupportRequestApi()

    def tearDown(self) -> None:
        pass

    def test_request_support(self) -> None:
        """Test case for request_support

        Create a support ticket
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Equinix Fabric API v4

    Equinix Fabric is an advanced software-defined interconnection solution that enables you to directly, securely and dynamically connect to distributed infrastructure and digital ecosystems on platform Equinix via a single port, Customers can use Fabric to connect to: </br> 1. Cloud Service Providers - Clouds, network and other service providers.  </br> 2. Enterprises - Other Equinix customers, vendors and partners.  </br> 3. Myself - Another customer instance deployed at Equinix. </br> </br> <b>Integrations (SDKs, Tools) links:</b> </br> <a href=\"https://deploy.equinix.com/labs/fabric-java\\\">Fabric Java SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/equinix-sdk-go\\\">Fabric Go SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/equinix-sdk-python\\\">Fabric Python SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/terraform-provider-equinix\\\">Equinix Terraform Provider</a> </br> <a href=\"https://deploy.equinix.com/labs/terraform-equinix-fabric\\\">Fabric Terraform Modules</a> </br> <a href=\"https://deploy.equinix.com/labs/pulumi-provider-equinix/\">Equinix Pulumi Provider</a> </br>

    The version of the OpenAPI document: 4.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.fabricv4.models.get_all_stream_subscription_response import GetAllStreamSubscriptionResponse

class TestGetAllStreamSubscriptionResponse(unittest.TestCase):
    """GetAllStreamSubscriptionResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GetAllStreamSubscriptionResponse:
        """Test GetAllStreamSubscriptionResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetAllStreamSubscriptionResponse`
        """
        model = GetAllStreamSubscriptionResponse()
        if include_optional:
            return GetAllStreamSubscriptionResponse(
                pagination = equinix.services.fabricv4.models.pagination.Pagination(
                    offset = 0, 
                    limit = 0, 
                    total = 0, 
                    next = '', 
                    previous = '', ),
                data = [
                    equinix.services.fabricv4.models.stream_subscription.StreamSubscription(
                        href = 'https://api.equinix.com/fabric/v4/streamSubscription/3c9b8e7a2-f3b1-4576-a4a9-1366a63df170', 
                        uuid = 'c9b8e7a2-f3b1-4576-a4a9-1366a63df170', 
                        type = 'STREAM_SUBSCRIPTION', 
                        name = '', 
                        description = '', 
                        project = equinix.services.fabricv4.models.project.Project(
                            project_id = '44f4c4f8-2f39-494e-838c-d8e640591be5', ), 
                        state = 'PROVISIONING', 
                        enabled = True, 
                        stream = equinix.services.fabricv4.models.stream_target.StreamTarget(
                            uuid = '657400f8-d360-11e9-bb65-2a2ae2dbcce5', ), 
                        filters = equinix.services.fabricv4.models.stream_subscription_filter.StreamSubscriptionFilter(
                            and = [
                                equinix.services.fabricv4.models.stream_filter.StreamFilter()
                                ], ), 
                        metric_selector = equinix.services.fabricv4.models.stream_subscription_selector.StreamSubscriptionSelector(
                            include = [
                                'equinix.fabric.connection.*'
                                ], 
                            except = [
                                'equinix.fabric.connection.*'
                                ], ), 
                        event_selector = equinix.services.fabricv4.models.stream_subscription_selector.StreamSubscriptionSelector(), 
                        sink = equinix.services.fabricv4.models.stream_subscription_sink.StreamSubscriptionSink(
                            uri = '', 
                            batch_enabled = False, 
                            batch_size_max = 56, 
                            batch_wait_time_max = 56, 
                            credential = equinix.services.fabricv4.models.stream_subscription_sink_credential.StreamSubscriptionSinkCredential(
                                access_token = '', 
                                integration_key = '', 
                                api_key = '', ), 
                            settings = equinix.services.fabricv4.models.stream_subscription_sink_setting.StreamSubscriptionSinkSetting(
                                event_index = '', 
                                metric_index = '', 
                                source = '', 
                                application_key = '', ), ), 
                        change_log = equinix.services.fabricv4.models.changelog.Changelog(
                            created_by = 'johnsmith', 
                            created_by_full_name = 'John Smith', 
                            created_by_email = 'john.smith@example.com', 
                            created_date_time = '2020-11-06T07:00Z', 
                            updated_by = 'johnsmith', 
                            updated_by_full_name = 'John Smith', 
                            updated_by_email = 'john.smith@example.com', 
                            updated_date_time = '2020-11-06T07:00Z', 
                            deleted_by = 'johnsmith', 
                            deleted_by_full_name = 'John Smith', 
                            deleted_by_email = 'john.smith@example.com', 
                            deleted_date_time = '2020-11-06T07:00Z', ), )
                    ]
            )
        else:
            return GetAllStreamSubscriptionResponse(
        )
        """

    def testGetAllStreamSubscriptionResponse(self):
        """Test GetAllStreamSubscriptionResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.plan_specs import PlanSpecs

class TestPlanSpecs(unittest.TestCase):
    """PlanSpecs unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PlanSpecs:
        """Test PlanSpecs
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PlanSpecs`
        """
        model = PlanSpecs()
        if include_optional:
            return PlanSpecs(
                cpus = [
                    equinix.services.metalv1.models.plan_specs_cpus_inner.Plan_specs_cpus_inner(
                        count = 56, 
                        href = '', 
                        type = '', )
                    ],
                drives = [
                    equinix.services.metalv1.models.plan_specs_drives_inner.Plan_specs_drives_inner(
                        category = '', 
                        count = 56, 
                        href = '', 
                        size = '3.84TB', 
                        type = '', )
                    ],
                features = equinix.services.metalv1.models.plan_specs_features.Plan_specs_features(
                    href = '', 
                    raid = True, 
                    txt = True, 
                    uefi = True, ),
                href = '',
                memory = equinix.services.metalv1.models.plan_specs_memory.Plan_specs_memory(
                    href = '', 
                    total = '', ),
                nics = [
                    equinix.services.metalv1.models.plan_specs_nics_inner.Plan_specs_nics_inner(
                        count = 2, 
                        href = '', 
                        type = '', )
                    ]
            )
        else:
            return PlanSpecs(
        )
        """

    def testPlanSpecs(self):
        """Test PlanSpecs"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.dedicated_port_create_input import DedicatedPortCreateInput

class TestDedicatedPortCreateInput(unittest.TestCase):
    """DedicatedPortCreateInput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DedicatedPortCreateInput:
        """Test DedicatedPortCreateInput
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DedicatedPortCreateInput`
        """
        model = DedicatedPortCreateInput()
        if include_optional:
            return DedicatedPortCreateInput(
                billing_account_name = '',
                contact_email = '',
                description = '',
                facility_id = '',
                href = '',
                metro = '',
                mode = 'standard',
                name = '',
                project = '',
                redundancy = '',
                speed = '10000000000',
                tags = [
                    ''
                    ],
                type = 'dedicated',
                use_case = ''
            )
        else:
            return DedicatedPortCreateInput(
                metro = '',
                name = '',
                redundancy = '',
                type = 'dedicated',
        )
        """

    def testDedicatedPortCreateInput(self):
        """Test DedicatedPortCreateInput"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.device import Device

class TestDevice(unittest.TestCase):
    """Device unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Device:
        """Test Device
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Device`
        """
        model = Device()
        if include_optional:
            return Device(
                actions = [
                    equinix.services.metalv1.models.device_actions_inner.Device_actions_inner(
                        href = '', 
                        name = '', 
                        type = '', )
                    ],
                always_pxe = True,
                billing_cycle = '',
                bonding_mode = 56,
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                created_by = None,
                customdata = { },
                description = '',
                facility = equinix.services.metalv1.models.facility.Facility(
                    address = equinix.services.metalv1.models.address.Address(
                        address2 = '', 
                        city = '', 
                        coordinates = equinix.services.metalv1.models.coordinates.Coordinates(
                            href = '', 
                            latitude = '', 
                            longitude = '', ), 
                        country = '', 
                        href = '', 
                        state = '', 
                        zip_code = '', ), 
                    code = '', 
                    features = ["baremetal","backend_transfer","global_ipv4"], 
                    href = '', 
                    id = '', 
                    ip_ranges = ["2604:1380::/36","147.75.192.0/21"], 
                    metro = null, 
                    name = '', ),
                firmware_set_id = '',
                hardware_reservation = equinix.services.metalv1.models.hardware_reservation.HardwareReservation(
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    custom_rate = 1050.5, 
                    device = equinix.services.metalv1.models.device.Device(
                        actions = [
                            equinix.services.metalv1.models.device_actions_inner.Device_actions_inner(
                                href = '', 
                                name = '', 
                                type = '', )
                            ], 
                        always_pxe = True, 
                        billing_cycle = '', 
                        bonding_mode = 56, 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        created_by = null, 
                        customdata = { }, 
                        description = '', 
                        facility = equinix.services.metalv1.models.facility.Facility(
                            address = equinix.services.metalv1.models.address.Address(
                                address2 = '', 
                                city = '', 
                                coordinates = equinix.services.metalv1.models.coordinates.Coordinates(
                                    href = '', 
                                    latitude = '', 
                                    longitude = '', ), 
                                country = '', 
                                href = '', 
                                state = '', 
                                zip_code = '', ), 
                            code = '', 
                            features = ["baremetal","backend_transfer","global_ipv4"], 
                            href = '', 
                            id = '', 
                            ip_ranges = ["2604:1380::/36","147.75.192.0/21"], 
                            metro = null, 
                            name = '', ), 
                        firmware_set_id = '', 
                        hostname = '', 
                        href = '', 
                        id = '', 
                        image_url = '', 
                        ip_addresses = [
                            equinix.services.metalv1.models.ip_assignment.IPAssignment(
                                address_family = 56, 
                                assigned_to = equinix.services.metalv1.models.href.Href(
                                    href = '', ), 
                                cidr = 56, 
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                enabled = True, 
                                gateway = '', 
                                global_ip = True, 
                                href = '', 
                                id = '', 
                                manageable = True, 
                                management = True, 
                                netmask = '', 
                                network = '', 
                                next_hop = '', 
                                parent_block = equinix.services.metalv1.models.parent_block.ParentBlock(
                                    cidr = 56, 
                                    href = '', 
                                    netmask = '', 
                                    network = '', ), 
                                public = True, 
                                state = 'pending', )
                            ], 
                        ipxe_script_url = '', 
                        iqn = '', 
                        locked = True, 
                        metro = null, 
                        network_frozen = True, 
                        network_ports = [
                            equinix.services.metalv1.models.port.Port(
                                bond = equinix.services.metalv1.models.bond_port_data.BondPortData(
                                    href = '', 
                                    id = '', 
                                    name = '', ), 
                                data = equinix.services.metalv1.models.port_data.PortData(
                                    bonded = True, 
                                    href = '', 
                                    mac = '', ), 
                                disbond_operation_supported = True, 
                                href = '', 
                                id = '', 
                                name = 'bond0', 
                                native_virtual_network = equinix.services.metalv1.models.virtual_network.VirtualNetwork(
                                    assigned_to_virtual_circuit = True, 
                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    description = '', 
                                    href = '', 
                                    id = '', 
                                    instances = [
                                        equinix.services.metalv1.models.device.Device(
                                            always_pxe = True, 
                                            billing_cycle = '', 
                                            bonding_mode = 56, 
                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            description = '', 
                                            firmware_set_id = '', 
                                            hostname = '', 
                                            href = '', 
                                            id = '', 
                                            image_url = '', 
                                            ipxe_script_url = '', 
                                            iqn = '', 
                                            locked = True, 
                                            network_frozen = True, 
                                            operating_system = equinix.services.metalv1.models.operating_system.OperatingSystem(
                                                build_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                                                default_operating_system = True, 
                                                deprecation_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                                                distro = '', 
                                                distro_label = '', 
                                                end_of_life_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                                                end_of_service_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                                                href = '', 
                                                id = '', 
                                                licensed = True, 
                                                lifecycle_state = '', 
                                                name = '', 
                                                preinstallable = True, 
                                                pricing = equinix.services.metalv1.models.pricing.pricing(), 
                                                provisionable_on = [
                                                    ''
                                                    ], 
                                                release_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                                                release_notes = '', 
                                                slug = '', 
                                                version = '', ), 
                                            plan = equinix.services.metalv1.models.plan.Plan(
                                                available_in = [
                                                    equinix.services.metalv1.models.plan_available_in_inner.Plan_available_in_inner(
                                                        href = '', 
                                                        price = equinix.services.metalv1.models.plan_available_in_inner_price.Plan_available_in_inner_price(
                                                            hour = 1.23, 
                                                            href = '', ), )
                                                    ], 
                                                available_in_metros = [
                                                    equinix.services.metalv1.models.plan_available_in_metros_inner.Plan_available_in_metros_inner(
                                                        href = '', )
                                                    ], 
                                                categories = [
                                                    ''
                                                    ], 
                                                class = 'm3.large.x86', 
                                                deployment_types = [
                                                    'on_demand'
                                                    ], 
                                                description = '', 
                                                href = '', 
                                                id = '', 
                                                legacy = True, 
                                                line = '', 
                                                name = '', 
                                                pricing = equinix.services.metalv1.models.pricing.pricing(), 
                                                slug = 'm3.large.x86', 
                                                specs = equinix.services.metalv1.models.plan_specs.Plan_specs(
                                                    cpus = [
                                                        equinix.services.metalv1.models.plan_specs_cpus_inner.Plan_specs_cpus_inner(
                                                            count = 56, 
                                                            href = '', 
                                                            type = '', )
                                                        ], 
                                                    drives = [
                                                        equinix.services.metalv1.models.plan_specs_drives_inner.Plan_specs_drives_inner(
                                                            category = '', 
                                                            count = 56, 
                                                            href = '', 
                                                            size = '3.84TB', 
                                                            type = '', )
                                                        ], 
                                                    features = equinix.services.metalv1.models.plan_specs_features.Plan_specs_features(
                                                        href = '', 
                                                        raid = True, 
                                                        txt = True, 
                                                        uefi = True, ), 
                                                    href = '', 
                                                    memory = equinix.services.metalv1.models.plan_specs_memory.Plan_specs_memory(
                                                        href = '', 
                                                        total = '', ), 
                                                    nics = [
                                                        equinix.services.metalv1.models.plan_specs_nics_inner.Plan_specs_nics_inner(
                                                            count = 2, 
                                                            href = '', 
                                                            type = '', )
                                                        ], ), 
                                                type = 'standard', ), 
                                            project = equinix.services.metalv1.models.project.Project(
                                                backend_transfer_enabled = True, 
                                                bgp_config = equinix.services.metalv1.models.href.Href(
                                                    href = '', ), 
                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                devices = [
                                                    
                                                    ], 
                                                href = '', 
                                                id = '', 
                                                invitations = [
                                                    
                                                    ], 
                                                max_devices = equinix.services.metalv1.models.max_devices.max_devices(), 
                                                members = [
                                                    
                                                    ], 
                                                memberships = [
                                                    
                                                    ], 
                                                name = '0', 
                                                network_status = equinix.services.metalv1.models.network_status.network_status(), 
                                                organization = , 
                                                payment_method = , 
                                                ssh_keys = [
                                                    
                                                    ], 
                                                tags = [
                                                    ''
                                                    ], 
                                                type = 'default', 
                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                url = '', 
                                                volumes = [
                                                    
                                                    ], ), 
                                            project_lite = null, 
                                            provisioning_events = [
                                                equinix.services.metalv1.models.event.Event(
                                                    body = '', 
                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    href = '', 
                                                    id = '', 
                                                    interpolated = '', 
                                                    ip = '', 
                                                    modified_by = equinix.services.metalv1.models.modified_by.modified_by(), 
                                                    relationships = [
                                                        
                                                        ], 
                                                    state = '', 
                                                    type = '', )
                                                ], 
                                            provisioning_percentage = 1.337, 
                                            root_password = '', 
                                            short_id = '', 
                                            sos = '', 
                                            spot_instance = True, 
                                            spot_price_max = 1.337, 
                                            ssh_keys = [
                                                
                                                ], 
                                            state = 'queued', 
                                            storage = equinix.services.metalv1.models.storage.Storage(
                                                disks = [
                                                    equinix.services.metalv1.models.disk.Disk(
                                                        href = '', 
                                                        partitions = [
                                                            equinix.services.metalv1.models.partition.Partition(
                                                                href = '', 
                                                                label = '', 
                                                                number = 56, 
                                                                size = '', )
                                                            ], 
                                                        wipe_table = True, )
                                                    ], 
                                                filesystems = [
                                                    equinix.services.metalv1.models.filesystem.Filesystem(
                                                        href = '', 
                                                        mount = equinix.services.metalv1.models.mount.Mount(
                                                            format = '', 
                                                            href = '', 
                                                            options = [
                                                                ''
                                                                ], 
                                                            point = '', ), )
                                                    ], 
                                                href = '', 
                                                raid = [
                                                    equinix.services.metalv1.models.raid.Raid(
                                                        href = '', 
                                                        level = '', 
                                                        name = '', )
                                                    ], ), 
                                            switch_uuid = '', 
                                            tags = [
                                                ''
                                                ], 
                                            termination_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            user = '', 
                                            userdata = '', 
                                            volumes = [
                                                
                                                ], )
                                        ], 
                                    metal_gateways = [
                                        equinix.services.metalv1.models.metal_gateway_lite.MetalGatewayLite(
                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            gateway_address = '10.1.2.1/27', 
                                            href = '', 
                                            id = '', 
                                            state = 'ready', 
                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            vlan = 1001, )
                                        ], 
                                    metro_code = '', 
                                    tags = , 
                                    vxlan = 56, ), 
                                network_type = 'layer2-bonded', 
                                type = 'NetworkPort', 
                                virtual_networks = [
                                    equinix.services.metalv1.models.virtual_network.VirtualNetwork(
                                        assigned_to_virtual_circuit = True, 
                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        description = '', 
                                        href = '', 
                                        id = '', 
                                        metro_code = '', 
                                        vxlan = 56, )
                                    ], )
                            ], 
                        operating_system = equinix.services.metalv1.models.operating_system.OperatingSystem(
                            build_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                            default_operating_system = True, 
                            deprecation_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                            distro = '', 
                            distro_label = '', 
                            end_of_life_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                            end_of_service_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                            href = '', 
                            id = '', 
                            licensed = True, 
                            lifecycle_state = '', 
                            name = '', 
                            preinstallable = True, 
                            pricing = equinix.services.metalv1.models.pricing.pricing(), 
                            release_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                            release_notes = '', 
                            slug = '', 
                            version = '', ), 
                        plan = equinix.services.metalv1.models.plan.Plan(
                            class = 'm3.large.x86', 
                            description = '', 
                            href = '', 
                            id = '', 
                            legacy = True, 
                            line = '', 
                            name = '', 
                            pricing = equinix.services.metalv1.models.pricing.pricing(), 
                            slug = 'm3.large.x86', 
                            type = 'standard', ), 
                        project = equinix.services.metalv1.models.project.Project(
                            backend_transfer_enabled = True, 
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            href = '', 
                            id = '', 
                            max_devices = equinix.services.metalv1.models.max_devices.max_devices(), 
                            name = '0', 
                            network_status = equinix.services.metalv1.models.network_status.network_status(), 
                            type = 'default', 
                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            url = '', ), 
                        project_lite = null, 
                        provisioning_events = [
                            equinix.services.metalv1.models.event.Event(
                                body = '', 
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                href = '', 
                                id = '', 
                                interpolated = '', 
                                ip = '', 
                                modified_by = equinix.services.metalv1.models.modified_by.modified_by(), 
                                state = '', 
                                type = '', )
                            ], 
                        provisioning_percentage = 1.337, 
                        root_password = '', 
                        short_id = '', 
                        sos = '', 
                        spot_instance = True, 
                        spot_price_max = 1.337, 
                        ssh_keys = , 
                        state = 'queued', 
                        storage = equinix.services.metalv1.models.storage.Storage(
                            href = '', ), 
                        switch_uuid = '', 
                        tags = , 
                        termination_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        user = '', 
                        userdata = '', 
                        volumes = , ), 
                    facility = equinix.services.metalv1.models.facility.Facility(
                        code = '', 
                        href = '', 
                        id = '', 
                        ip_ranges = ["2604:1380::/36","147.75.192.0/21"], 
                        name = '', ), 
                    href = '', 
                    id = '', 
                    need_of_service = True, 
                    plan = , 
                    project = , 
                    provisionable = True, 
                    short_id = '', 
                    spare = True, 
                    switch_uuid = '', 
                    termination_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
                hostname = '',
                href = '',
                id = '',
                image_url = '',
                ip_addresses = [
                    equinix.services.metalv1.models.ip_assignment.IPAssignment(
                        address = '', 
                        address_family = 56, 
                        assigned_to = equinix.services.metalv1.models.href.Href(
                            href = '', ), 
                        cidr = 56, 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        enabled = True, 
                        gateway = '', 
                        global_ip = True, 
                        href = '', 
                        id = '', 
                        manageable = True, 
                        management = True, 
                        metro = null, 
                        netmask = '', 
                        network = '', 
                        next_hop = '', 
                        parent_block = equinix.services.metalv1.models.parent_block.ParentBlock(
                            cidr = 56, 
                            href = '', 
                            netmask = '', 
                            network = '', ), 
                        public = True, 
                        state = 'pending', )
                    ],
                ipxe_script_url = '',
                iqn = '',
                locked = True,
                metro = None,
                network_frozen = True,
                network_ports = [
                    equinix.services.metalv1.models.port.Port(
                        bond = equinix.services.metalv1.models.bond_port_data.BondPortData(
                            href = '', 
                            id = '', 
                            name = '', ), 
                        data = equinix.services.metalv1.models.port_data.PortData(
                            bonded = True, 
                            href = '', 
                            mac = '', ), 
                        disbond_operation_supported = True, 
                        href = '', 
                        id = '', 
                        name = 'bond0', 
                        native_virtual_network = equinix.services.metalv1.models.virtual_network.VirtualNetwork(
                            assigned_to = equinix.services.metalv1.models.project.Project(
                                backend_transfer_enabled = True, 
                                bgp_config = equinix.services.metalv1.models.href.Href(
                                    href = '', ), 
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                customdata = equinix.services.metalv1.models.customdata.customdata(), 
                                devices = [
                                    equinix.services.metalv1.models.href.Href(
                                        href = '', )
                                    ], 
                                href = '', 
                                id = '', 
                                invitations = [
                                    
                                    ], 
                                max_devices = equinix.services.metalv1.models.max_devices.max_devices(), 
                                members = [
                                    
                                    ], 
                                memberships = [
                                    
                                    ], 
                                name = '0', 
                                network_status = equinix.services.metalv1.models.network_status.network_status(), 
                                organization = , 
                                payment_method = , 
                                ssh_keys = [
                                    
                                    ], 
                                tags = [
                                    ''
                                    ], 
                                type = 'default', 
                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                url = '', 
                                volumes = [
                                    
                                    ], ), 
                            assigned_to_virtual_circuit = True, 
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            description = '', 
                            facility = , 
                            href = '', 
                            id = '', 
                            instances = [
                                equinix.services.metalv1.models.device.Device(
                                    actions = [
                                        equinix.services.metalv1.models.device_actions_inner.Device_actions_inner(
                                            href = '', 
                                            name = '', 
                                            type = '', )
                                        ], 
                                    always_pxe = True, 
                                    billing_cycle = '', 
                                    bonding_mode = 56, 
                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    created_by = null, 
                                    customdata = { }, 
                                    description = '', 
                                    firmware_set_id = '', 
                                    hardware_reservation = equinix.services.metalv1.models.hardware_reservation.HardwareReservation(
                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        custom_rate = 1050.5, 
                                        device = equinix.services.metalv1.models.device.Device(
                                            always_pxe = True, 
                                            billing_cycle = '', 
                                            bonding_mode = 56, 
                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            description = '', 
                                            firmware_set_id = '', 
                                            hostname = '', 
                                            href = '', 
                                            id = '', 
                                            image_url = '', 
                                            ip_addresses = [
                                                equinix.services.metalv1.models.ip_assignment.IPAssignment(
                                                    address = '', 
                                                    address_family = 56, 
                                                    assigned_to = , 
                                                    cidr = 56, 
                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    enabled = True, 
                                                    gateway = '', 
                                                    global_ip = True, 
                                                    href = '', 
                                                    id = '', 
                                                    manageable = True, 
                                                    management = True, 
                                                    metro = null, 
                                                    netmask = '', 
                                                    network = '', 
                                                    next_hop = '', 
                                                    parent_block = equinix.services.metalv1.models.parent_block.ParentBlock(
                                                        cidr = 56, 
                                                        href = '', 
                                                        netmask = '', 
                                                        network = '', ), 
                                                    public = True, 
                                                    state = 'pending', )
                                                ], 
                                            ipxe_script_url = '', 
                                            iqn = '', 
                                            locked = True, 
                                            metro = null, 
                                            network_frozen = True, 
                                            operating_system = equinix.services.metalv1.models.operating_system.OperatingSystem(
                                                build_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                                                default_operating_system = True, 
                                                deprecation_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                                                distro = '', 
                                                distro_label = '', 
                                                end_of_life_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                                                end_of_service_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                                                href = '', 
                                                id = '', 
                                                licensed = True, 
                                                lifecycle_state = '', 
                                                name = '', 
                                                preinstallable = True, 
                                                pricing = equinix.services.metalv1.models.pricing.pricing(), 
                                                provisionable_on = [
                                                    ''
                                                    ], 
                                                release_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                                                release_notes = '', 
                                                slug = '', 
                                                version = '', ), 
                                            plan = equinix.services.metalv1.models.plan.Plan(
                                                available_in = [
                                                    equinix.services.metalv1.models.plan_available_in_inner.Plan_available_in_inner(
                                                        href = '', 
                                                        price = equinix.services.metalv1.models.plan_available_in_inner_price.Plan_available_in_inner_price(
                                                            hour = 1.23, 
                                                            href = '', ), )
                                                    ], 
                                                available_in_metros = [
                                                    equinix.services.metalv1.models.plan_available_in_metros_inner.Plan_available_in_metros_inner(
                                                        href = '', )
                                                    ], 
                                                categories = [
                                                    ''
                                                    ], 
                                                class = 'm3.large.x86', 
                                                deployment_types = [
                                                    'on_demand'
                                                    ], 
                                                description = '', 
                                                href = '', 
                                                id = '', 
                                                legacy = True, 
                                                line = '', 
                                                name = '', 
                                                pricing = equinix.services.metalv1.models.pricing.pricing(), 
                                                slug = 'm3.large.x86', 
                                                specs = equinix.services.metalv1.models.plan_specs.Plan_specs(
                                                    cpus = [
                                                        equinix.services.metalv1.models.plan_specs_cpus_inner.Plan_specs_cpus_inner(
                                                            count = 56, 
                                                            href = '', 
                                                            type = '', )
                                                        ], 
                                                    drives = [
                                                        equinix.services.metalv1.models.plan_specs_drives_inner.Plan_specs_drives_inner(
                                                            category = '', 
                                                            count = 56, 
                                                            href = '', 
                                                            size = '3.84TB', 
                                                            type = '', )
                                                        ], 
                                                    features = equinix.services.metalv1.models.plan_specs_features.Plan_specs_features(
                                                        href = '', 
                                                        raid = True, 
                                                        txt = True, 
                                                        uefi = True, ), 
                                                    href = '', 
                                                    memory = equinix.services.metalv1.models.plan_specs_memory.Plan_specs_memory(
                                                        href = '', 
                                                        total = '', ), 
                                                    nics = [
                                                        equinix.services.metalv1.models.plan_specs_nics_inner.Plan_specs_nics_inner(
                                                            count = 2, 
                                                            href = '', 
                                                            type = '', )
                                                        ], ), 
                                                type = 'standard', ), 
                                            project = equinix.services.metalv1.models.project.Project(
                                                backend_transfer_enabled = True, 
                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                href = '', 
                                                id = '', 
                                                max_devices = equinix.services.metalv1.models.max_devices.max_devices(), 
                                                name = '0', 
                                                network_status = equinix.services.metalv1.models.network_status.network_status(), 
                                                type = 'default', 
                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                url = '', ), 
                                            project_lite = null, 
                                            provisioning_events = [
                                                equinix.services.metalv1.models.event.Event(
                                                    body = '', 
                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    href = '', 
                                                    id = '', 
                                                    interpolated = '', 
                                                    ip = '', 
                                                    modified_by = equinix.services.metalv1.models.modified_by.modified_by(), 
                                                    relationships = [
                                                        
                                                        ], 
                                                    state = '', 
                                                    type = '', )
                                                ], 
                                            provisioning_percentage = 1.337, 
                                            root_password = '', 
                                            short_id = '', 
                                            sos = '', 
                                            spot_instance = True, 
                                            spot_price_max = 1.337, 
                                            state = 'queued', 
                                            storage = equinix.services.metalv1.models.storage.Storage(
                                                disks = [
                                                    equinix.services.metalv1.models.disk.Disk(
                                                        href = '', 
                                                        partitions = [
                                                            equinix.services.metalv1.models.partition.Partition(
                                                                href = '', 
                                                                label = '', 
                                                                number = 56, 
                                                                size = '', )
                                                            ], 
                                                        wipe_table = True, )
                                                    ], 
                                                filesystems = [
                                                    equinix.services.metalv1.models.filesystem.Filesystem(
                                                        href = '', 
                                                        mount = equinix.services.metalv1.models.mount.Mount(
                                                            format = '', 
                                                            href = '', 
                                                            options = [
                                                                ''
                                                                ], 
                                                            point = '', ), )
                                                    ], 
                                                href = '', 
                                                raid = [
                                                    equinix.services.metalv1.models.raid.Raid(
                                                        href = '', 
                                                        level = '', 
                                                        name = '', )
                                                    ], ), 
                                            switch_uuid = '', 
                                            termination_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            user = '', 
                                            userdata = '', ), 
                                        href = '', 
                                        id = '', 
                                        need_of_service = True, 
                                        plan = equinix.services.metalv1.models.plan.Plan(
                                            class = 'm3.large.x86', 
                                            description = '', 
                                            href = '', 
                                            id = '', 
                                            legacy = True, 
                                            line = '', 
                                            name = '', 
                                            pricing = equinix.services.metalv1.models.pricing.pricing(), 
                                            slug = 'm3.large.x86', 
                                            type = 'standard', ), 
                                        project = , 
                                        provisionable = True, 
                                        short_id = '', 
                                        spare = True, 
                                        switch_uuid = '', 
                                        termination_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                                    hostname = '', 
                                    href = '', 
                                    id = '', 
                                    image_url = '', 
                                    ip_addresses = [
                                        equinix.services.metalv1.models.ip_assignment.IPAssignment(
                                            address = '', 
                                            address_family = 56, 
                                            assigned_to = , 
                                            cidr = 56, 
                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            enabled = True, 
                                            gateway = '', 
                                            global_ip = True, 
                                            href = '', 
                                            id = '', 
                                            manageable = True, 
                                            management = True, 
                                            netmask = '', 
                                            network = '', 
                                            next_hop = '', 
                                            public = True, 
                                            state = 'pending', )
                                        ], 
                                    ipxe_script_url = '', 
                                    iqn = '', 
                                    locked = True, 
                                    metro = null, 
                                    network_frozen = True, 
                                    operating_system = equinix.services.metalv1.models.operating_system.OperatingSystem(
                                        build_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                                        default_operating_system = True, 
                                        deprecation_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                                        distro = '', 
                                        distro_label = '', 
                                        end_of_life_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                                        end_of_service_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                                        href = '', 
                                        id = '', 
                                        licensed = True, 
                                        lifecycle_state = '', 
                                        name = '', 
                                        preinstallable = True, 
                                        pricing = equinix.services.metalv1.models.pricing.pricing(), 
                                        release_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                                        release_notes = '', 
                                        slug = '', 
                                        version = '', ), 
                                    plan = , 
                                    project = , 
                                    project_lite = null, 
                                    provisioning_events = [
                                        equinix.services.metalv1.models.event.Event(
                                            body = '', 
                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            href = '', 
                                            id = '', 
                                            interpolated = '', 
                                            ip = '', 
                                            modified_by = equinix.services.metalv1.models.modified_by.modified_by(), 
                                            state = '', 
                                            type = '', )
                                        ], 
                                    provisioning_percentage = 1.337, 
                                    root_password = '', 
                                    short_id = '', 
                                    sos = '', 
                                    spot_instance = True, 
                                    spot_price_max = 1.337, 
                                    state = 'queued', 
                                    storage = equinix.services.metalv1.models.storage.Storage(
                                        href = '', ), 
                                    switch_uuid = '', 
                                    termination_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    user = '', 
                                    userdata = '', )
                                ], 
                            metal_gateways = [
                                equinix.services.metalv1.models.metal_gateway_lite.MetalGatewayLite(
                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    gateway_address = '10.1.2.1/27', 
                                    href = '', 
                                    id = '', 
                                    state = 'ready', 
                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    vlan = 1001, )
                                ], 
                            metro = equinix.services.metalv1.models.metro.Metro(
                                code = '', 
                                country = '', 
                                href = '', 
                                id = '', 
                                name = '', ), 
                            metro_code = '', 
                            tags = [
                                ''
                                ], 
                            vxlan = 56, ), 
                        network_type = 'layer2-bonded', 
                        type = 'NetworkPort', 
                        virtual_networks = [
                            equinix.services.metalv1.models.virtual_network.VirtualNetwork(
                                assigned_to_virtual_circuit = True, 
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                description = '', 
                                href = '', 
                                id = '', 
                                metro_code = '', 
                                vxlan = 56, )
                            ], )
                    ],
                operating_system = equinix.services.metalv1.models.operating_system.OperatingSystem(
                    build_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                    default_operating_system = True, 
                    deprecation_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                    distro = '', 
                    distro_label = '', 
                    end_of_life_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                    end_of_service_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                    href = '', 
                    id = '', 
                    licensed = True, 
                    lifecycle_state = '', 
                    name = '', 
                    preinstallable = True, 
                    pricing = equinix.services.metalv1.models.pricing.pricing(), 
                    provisionable_on = [
                        ''
                        ], 
                    release_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                    release_notes = '', 
                    slug = '', 
                    version = '', ),
                plan = equinix.services.metalv1.models.plan.Plan(
                    available_in = [
                        equinix.services.metalv1.models.plan_available_in_inner.Plan_available_in_inner(
                            href = '', 
                            price = equinix.services.metalv1.models.plan_available_in_inner_price.Plan_available_in_inner_price(
                                hour = 1.23, 
                                href = '', ), )
                        ], 
                    available_in_metros = [
                        equinix.services.metalv1.models.plan_available_in_metros_inner.Plan_available_in_metros_inner(
                            href = '', )
                        ], 
                    categories = [
                        ''
                        ], 
                    class = 'm3.large.x86', 
                    deployment_types = [
                        'on_demand'
                        ], 
                    description = '', 
                    href = '', 
                    id = '', 
                    legacy = True, 
                    line = '', 
                    name = '', 
                    pricing = equinix.services.metalv1.models.pricing.pricing(), 
                    slug = 'm3.large.x86', 
                    specs = equinix.services.metalv1.models.plan_specs.Plan_specs(
                        cpus = [
                            equinix.services.metalv1.models.plan_specs_cpus_inner.Plan_specs_cpus_inner(
                                count = 56, 
                                href = '', 
                                type = '', )
                            ], 
                        drives = [
                            equinix.services.metalv1.models.plan_specs_drives_inner.Plan_specs_drives_inner(
                                category = '', 
                                count = 56, 
                                href = '', 
                                size = '3.84TB', 
                                type = '', )
                            ], 
                        features = equinix.services.metalv1.models.plan_specs_features.Plan_specs_features(
                            href = '', 
                            raid = True, 
                            txt = True, 
                            uefi = True, ), 
                        href = '', 
                        memory = equinix.services.metalv1.models.plan_specs_memory.Plan_specs_memory(
                            href = '', 
                            total = '', ), 
                        nics = [
                            equinix.services.metalv1.models.plan_specs_nics_inner.Plan_specs_nics_inner(
                                count = 2, 
                                href = '', 
                                type = '', )
                            ], ), 
                    type = 'standard', ),
                project = equinix.services.metalv1.models.project.Project(
                    backend_transfer_enabled = True, 
                    bgp_config = equinix.services.metalv1.models.href.Href(
                        href = '', ), 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    customdata = equinix.services.metalv1.models.customdata.customdata(), 
                    devices = [
                        equinix.services.metalv1.models.href.Href(
                            href = '', )
                        ], 
                    href = '', 
                    id = '', 
                    invitations = [
                        
                        ], 
                    max_devices = equinix.services.metalv1.models.max_devices.max_devices(), 
                    members = [
                        
                        ], 
                    memberships = [
                        
                        ], 
                    name = '0', 
                    network_status = equinix.services.metalv1.models.network_status.network_status(), 
                    organization = , 
                    payment_method = , 
                    ssh_keys = [
                        
                        ], 
                    tags = [
                        ''
                        ], 
                    type = 'default', 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    url = '', 
                    volumes = [
                        
                        ], ),
                project_lite = None,
                provisioning_events = [
                    equinix.services.metalv1.models.event.Event(
                        body = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        href = '', 
                        id = '', 
                        interpolated = '', 
                        ip = '', 
                        modified_by = equinix.services.metalv1.models.modified_by.modified_by(), 
                        relationships = [
                            equinix.services.metalv1.models.href.Href(
                                href = '', )
                            ], 
                        state = '', 
                        type = '', )
                    ],
                provisioning_percentage = 1.337,
                root_password = '',
                short_id = '',
                sos = '',
                spot_instance = True,
                spot_price_max = 1.337,
                ssh_keys = [
                    equinix.services.metalv1.models.href.Href(
                        href = '', )
                    ],
                state = 'queued',
                storage = equinix.services.metalv1.models.storage.Storage(
                    disks = [
                        equinix.services.metalv1.models.disk.Disk(
                            device = '', 
                            href = '', 
                            partitions = [
                                equinix.services.metalv1.models.partition.Partition(
                                    href = '', 
                                    label = '', 
                                    number = 56, 
                                    size = '', )
                                ], 
                            wipe_table = True, )
                        ], 
                    filesystems = [
                        equinix.services.metalv1.models.filesystem.Filesystem(
                            href = '', 
                            mount = equinix.services.metalv1.models.mount.Mount(
                                device = '', 
                                format = '', 
                                href = '', 
                                options = [
                                    ''
                                    ], 
                                point = '', ), )
                        ], 
                    href = '', 
                    raid = [
                        equinix.services.metalv1.models.raid.Raid(
                            devices = [
                                ''
                                ], 
                            href = '', 
                            level = '', 
                            name = '', )
                        ], ),
                switch_uuid = '',
                tags = [
                    ''
                    ],
                termination_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                user = '',
                userdata = '',
                volumes = [
                    equinix.services.metalv1.models.href.Href(
                        href = '', )
                    ]
            )
        else:
            return Device(
        )
        """

    def testDevice(self):
        """Test Device"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional, Union
from equinix.services.metalv1.models.device_actions_inner import DeviceActionsInner
from equinix.services.metalv1.models.device_created_by import DeviceCreatedBy
from equinix.services.metalv1.models.device_metro import DeviceMetro
from equinix.services.metalv1.models.device_project_lite import DeviceProjectLite
from equinix.services.metalv1.models.event import Event
from equinix.services.metalv1.models.facility import Facility
from equinix.services.metalv1.models.href import Href
from equinix.services.metalv1.models.ip_assignment import IPAssignment
from equinix.services.metalv1.models.operating_system import OperatingSystem
from equinix.services.metalv1.models.plan import Plan
from equinix.services.metalv1.models.project import Project
from equinix.services.metalv1.models.storage import Storage
from typing import Optional, Set
from typing_extensions import Self

class Device(BaseModel):
    """
    Device
    """ # noqa: E501
    actions: Optional[List[DeviceActionsInner]] = Field(default=None, description="Actions supported by the device instance.")
    always_pxe: Optional[StrictBool] = None
    billing_cycle: Optional[StrictStr] = None
    bonding_mode: Optional[StrictInt] = None
    created_at: Optional[datetime] = None
    created_by: Optional[DeviceCreatedBy] = None
    customdata: Optional[Dict[str, Any]] = None
    description: Optional[StrictStr] = None
    facility: Optional[Facility] = None
    firmware_set_id: Optional[StrictStr] = Field(default=None, description="The UUID of the firmware set to associate with the device.")
    hardware_reservation: Optional[HardwareReservation] = None
    hostname: Optional[StrictStr] = None
    href: Optional[StrictStr] = None
    id: Optional[StrictStr] = None
    image_url: Optional[StrictStr] = None
    ip_addresses: Optional[List[IPAssignment]] = None
    ipxe_script_url: Optional[StrictStr] = None
    iqn: Optional[StrictStr] = None
    locked: Optional[StrictBool] = Field(default=None, description="Prevents accidental deletion of this resource when set to true.")
    metro: Optional[DeviceMetro] = None
    network_frozen: Optional[StrictBool] = Field(default=None, description="Whether network mode changes such as converting to/from Layer2 or Layer3 networking, bonding or disbonding network interfaces are permitted for the device.")
    network_ports: Optional[List[Port]] = Field(default=None, description="By default, servers at Equinix Metal are configured in a “bonded” mode using LACP (Link Aggregation Control Protocol). Each 2-NIC server is configured with a single bond (namely bond0) with both interfaces eth0 and eth1 as members of the bond in a default Layer 3 mode. Some device plans may have a different number of ports and bonds available.")
    operating_system: Optional[OperatingSystem] = None
    plan: Optional[Plan] = None
    project: Optional[Project] = None
    project_lite: Optional[DeviceProjectLite] = None
    provisioning_events: Optional[List[Event]] = None
    provisioning_percentage: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="Only visible while device provisioning")
    root_password: Optional[StrictStr] = Field(default=None, description="Root password is automatically generated when server is provisioned and it is removed after 24 hours")
    short_id: Optional[StrictStr] = None
    sos: Optional[StrictStr] = Field(default=None, description="Hostname used to connect to the instance via the SOS (Serial over SSH) out-of-band console.")
    spot_instance: Optional[StrictBool] = Field(default=None, description="Whether or not the device is a spot instance.")
    spot_price_max: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="The maximum price per hour you are willing to pay to keep this spot instance.  If you are outbid, the termination will be set allowing two minutes before shutdown.")
    ssh_keys: Optional[List[Href]] = None
    state: Optional[StrictStr] = Field(default=None, description="The current state the instance is in.  * When an instance is initially created it will be in the `queued` state until it is picked up by the provisioner. * Once provisioning has begun on the instance it's state will move to `provisioning`. * When an instance is deleted, it will move to `deprovisioning` state until the deprovision is completed and the instance state moves to `deleted`. * If an instance fails to provision or deprovision it will move to `failed` state. * Once an instance has completed provisioning it will move to `active` state. * If an instance is currently powering off or powering on it will move to `powering_off` or `powering_on` states respectively.  * When the instance is powered off completely it will move to the `inactive` state. * When an instance is powered on completely it will move to the `active` state. * Using the reinstall action to install a new OS on the instance will cause the instance state to change to `reinstalling`. * When the reinstall action is complete the instance will move to `active` state.")
    storage: Optional[Storage] = None
    switch_uuid: Optional[StrictStr] = Field(default=None, description="Switch short id. This can be used to determine if two devices are connected to the same switch, for example.")
    tags: Optional[List[StrictStr]] = None
    termination_time: Optional[datetime] = Field(default=None, description="When the device will be terminated. If you don't supply timezone info, the timestamp is assumed to be in UTC.  This is commonly set in advance for ephemeral spot market instances but this field may also be set with on-demand and reservation instances to automatically delete the resource at a given time. The termination time can also be used to release a hardware reservation instance at a given time, keeping the reservation open for other uses.  On a spot market device, the termination time will be set automatically when outbid.")
    updated_at: Optional[datetime] = None
    user: Optional[StrictStr] = None
    userdata: Optional[StrictStr] = None
    volumes: Optional[List[Href]] = None
    __properties: ClassVar[List[str]] = ["actions", "always_pxe", "billing_cycle", "bonding_mode", "created_at", "created_by", "customdata", "description", "facility", "firmware_set_id", "hardware_reservation", "hostname", "href", "id", "image_url", "ip_addresses", "ipxe_script_url", "iqn", "locked", "metro", "network_frozen", "network_ports", "operating_system", "plan", "project", "project_lite", "provisioning_events", "provisioning_percentage", "root_password", "short_id", "sos", "spot_instance", "spot_price_max", "ssh_keys", "state", "storage", "switch_uuid", "tags", "termination_time", "updated_at", "user", "userdata", "volumes"]

    @field_validator('state')
    def state_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['queued', 'provisioning', 'deprovisioning', 'reinstalling', 'active', 'inactive', 'failed', 'powering_on', 'powering_off', 'deleted']):
            raise ValueError("must be one of enum values ('queued', 'provisioning', 'deprovisioning', 'reinstalling', 'active', 'inactive', 'failed', 'powering_on', 'powering_off', 'deleted')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Device from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in actions (list)
        _items = []
        if self.actions:
            for _item in self.actions:
                if _item:
                    _items.append(_item.to_dict())
            _dict['actions'] = _items
        # override the default output from pydantic by calling `to_dict()` of created_by
        if self.created_by:
            _dict['created_by'] = self.created_by.to_dict()
        # override the default output from pydantic by calling `to_dict()` of facility
        if self.facility:
            _dict['facility'] = self.facility.to_dict()
        # override the default output from pydantic by calling `to_dict()` of hardware_reservation
        if self.hardware_reservation:
            _dict['hardware_reservation'] = self.hardware_reservation.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in ip_addresses (list)
        _items = []
        if self.ip_addresses:
            for _item in self.ip_addresses:
                if _item:
                    _items.append(_item.to_dict())
            _dict['ip_addresses'] = _items
        # override the default output from pydantic by calling `to_dict()` of metro
        if self.metro:
            _dict['metro'] = self.metro.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in network_ports (list)
        _items = []
        if self.network_ports:
            for _item in self.network_ports:
                if _item:
                    _items.append(_item.to_dict())
            _dict['network_ports'] = _items
        # override the default output from pydantic by calling `to_dict()` of operating_system
        if self.operating_system:
            _dict['operating_system'] = self.operating_system.to_dict()
        # override the default output from pydantic by calling `to_dict()` of plan
        if self.plan:
            _dict['plan'] = self.plan.to_dict()
        # override the default output from pydantic by calling `to_dict()` of project
        if self.project:
            _dict['project'] = self.project.to_dict()
        # override the default output from pydantic by calling `to_dict()` of project_lite
        if self.project_lite:
            _dict['project_lite'] = self.project_lite.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in provisioning_events (list)
        _items = []
        if self.provisioning_events:
            for _item in self.provisioning_events:
                if _item:
                    _items.append(_item.to_dict())
            _dict['provisioning_events'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in ssh_keys (list)
        _items = []
        if self.ssh_keys:
            for _item in self.ssh_keys:
                if _item:
                    _items.append(_item.to_dict())
            _dict['ssh_keys'] = _items
        # override the default output from pydantic by calling `to_dict()` of storage
        if self.storage:
            _dict['storage'] = self.storage.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in volumes (list)
        _items = []
        if self.volumes:
            for _item in self.volumes:
                if _item:
                    _items.append(_item.to_dict())
            _dict['volumes'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Device from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "actions": [DeviceActionsInner.from_dict(_item) for _item in obj["actions"]] if obj.get("actions") is not None else None,
            "always_pxe": obj.get("always_pxe"),
            "billing_cycle": obj.get("billing_cycle"),
            "bonding_mode": obj.get("bonding_mode"),
            "created_at": obj.get("created_at"),
            "created_by": DeviceCreatedBy.from_dict(obj["created_by"]) if obj.get("created_by") is not None else None,
            "customdata": obj.get("customdata"),
            "description": obj.get("description"),
            "facility": Facility.from_dict(obj["facility"]) if obj.get("facility") is not None else None,
            "firmware_set_id": obj.get("firmware_set_id"),
            "hardware_reservation": HardwareReservation.from_dict(obj["hardware_reservation"]) if obj.get("hardware_reservation") is not None else None,
            "hostname": obj.get("hostname"),
            "href": obj.get("href"),
            "id": obj.get("id"),
            "image_url": obj.get("image_url"),
            "ip_addresses": [IPAssignment.from_dict(_item) for _item in obj["ip_addresses"]] if obj.get("ip_addresses") is not None else None,
            "ipxe_script_url": obj.get("ipxe_script_url"),
            "iqn": obj.get("iqn"),
            "locked": obj.get("locked"),
            "metro": DeviceMetro.from_dict(obj["metro"]) if obj.get("metro") is not None else None,
            "network_frozen": obj.get("network_frozen"),
            "network_ports": [Port.from_dict(_item) for _item in obj["network_ports"]] if obj.get("network_ports") is not None else None,
            "operating_system": OperatingSystem.from_dict(obj["operating_system"]) if obj.get("operating_system") is not None else None,
            "plan": Plan.from_dict(obj["plan"]) if obj.get("plan") is not None else None,
            "project": Project.from_dict(obj["project"]) if obj.get("project") is not None else None,
            "project_lite": DeviceProjectLite.from_dict(obj["project_lite"]) if obj.get("project_lite") is not None else None,
            "provisioning_events": [Event.from_dict(_item) for _item in obj["provisioning_events"]] if obj.get("provisioning_events") is not None else None,
            "provisioning_percentage": obj.get("provisioning_percentage"),
            "root_password": obj.get("root_password"),
            "short_id": obj.get("short_id"),
            "sos": obj.get("sos"),
            "spot_instance": obj.get("spot_instance"),
            "spot_price_max": obj.get("spot_price_max"),
            "ssh_keys": [Href.from_dict(_item) for _item in obj["ssh_keys"]] if obj.get("ssh_keys") is not None else None,
            "state": obj.get("state"),
            "storage": Storage.from_dict(obj["storage"]) if obj.get("storage") is not None else None,
            "switch_uuid": obj.get("switch_uuid"),
            "tags": obj.get("tags"),
            "termination_time": obj.get("termination_time"),
            "updated_at": obj.get("updated_at"),
            "user": obj.get("user"),
            "userdata": obj.get("userdata"),
            "volumes": [Href.from_dict(_item) for _item in obj["volumes"]] if obj.get("volumes") is not None else None
        })
        return _obj

from equinix.services.metalv1.models.hardware_reservation import HardwareReservation
from equinix.services.metalv1.models.port import Port
# TODO: Rewrite to not use raise_errors
Device.model_rebuild(raise_errors=False)




# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from equinix.services.metalv1.models.address import Address
from equinix.services.metalv1.models.device_metro import DeviceMetro
from typing import Optional, Set
from typing_extensions import Self

class Facility(BaseModel):
    """
    Facility
    """ # noqa: E501
    address: Optional[Address] = None
    code: Optional[StrictStr] = None
    features: Optional[List[StrictStr]] = None
    href: Optional[StrictStr] = None
    id: Optional[StrictStr] = None
    ip_ranges: Optional[List[StrictStr]] = Field(default=None, description="IP ranges registered in facility. Can be used for GeoIP location")
    metro: Optional[DeviceMetro] = None
    name: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["address", "code", "features", "href", "id", "ip_ranges", "metro", "name"]

    @field_validator('features')
    def features_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        for i in value:
            if i not in set(['baremetal', 'backend_transfer', 'layer_2', 'global_ipv4', 'ibx']):
                raise ValueError("each list item must be one of ('baremetal', 'backend_transfer', 'layer_2', 'global_ipv4', 'ibx')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Facility from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of address
        if self.address:
            _dict['address'] = self.address.to_dict()
        # override the default output from pydantic by calling `to_dict()` of metro
        if self.metro:
            _dict['metro'] = self.metro.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Facility from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "address": Address.from_dict(obj["address"]) if obj.get("address") is not None else None,
            "code": obj.get("code"),
            "features": obj.get("features"),
            "href": obj.get("href"),
            "id": obj.get("id"),
            "ip_ranges": obj.get("ip_ranges"),
            "metro": DeviceMetro.from_dict(obj["metro"]) if obj.get("metro") is not None else None,
            "name": obj.get("name")
        })
        return _obj





# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from equinix.services.metalv1.models.email_input import EmailInput
from typing import Optional, Set
from typing_extensions import Self

class UserCreateInput(BaseModel):
    """
    UserCreateInput
    """ # noqa: E501
    company_name: Optional[StrictStr] = None
    company_url: Optional[StrictStr] = None
    customdata: Optional[Dict[str, Any]] = None
    emails: List[EmailInput]
    first_name: StrictStr
    href: Optional[StrictStr] = None
    invitation_id: Optional[StrictStr] = None
    last_name: StrictStr
    level: Optional[StrictStr] = None
    nonce: Optional[StrictStr] = None
    password: Optional[StrictStr] = None
    phone_number: Optional[StrictStr] = None
    social_accounts: Optional[Dict[str, Any]] = None
    timezone: Optional[StrictStr] = None
    title: Optional[StrictStr] = None
    two_factor_auth: Optional[StrictStr] = None
    verified_at: Optional[datetime] = None
    __properties: ClassVar[List[str]] = ["company_name", "company_url", "customdata", "emails", "first_name", "href", "invitation_id", "last_name", "level", "nonce", "password", "phone_number", "social_accounts", "timezone", "title", "two_factor_auth", "verified_at"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of UserCreateInput from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in emails (list)
        _items = []
        if self.emails:
            for _item in self.emails:
                if _item:
                    _items.append(_item.to_dict())
            _dict['emails'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of UserCreateInput from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "company_name": obj.get("company_name"),
            "company_url": obj.get("company_url"),
            "customdata": obj.get("customdata"),
            "emails": [EmailInput.from_dict(_item) for _item in obj["emails"]] if obj.get("emails") is not None else None,
            "first_name": obj.get("first_name"),
            "href": obj.get("href"),
            "invitation_id": obj.get("invitation_id"),
            "last_name": obj.get("last_name"),
            "level": obj.get("level"),
            "nonce": obj.get("nonce"),
            "password": obj.get("password"),
            "phone_number": obj.get("phone_number"),
            "social_accounts": obj.get("social_accounts"),
            "timezone": obj.get("timezone"),
            "title": obj.get("title"),
            "two_factor_auth": obj.get("two_factor_auth"),
            "verified_at": obj.get("verified_at")
        })
        return _obj





# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
import pprint
from pydantic import BaseModel, ConfigDict, Field, StrictStr, ValidationError, field_validator
from typing import Any, List, Optional
from equinix.services.metalv1.models.dedicated_port_create_input import DedicatedPortCreateInput
from equinix.services.metalv1.models.shared_port_vc_vlan_create_input import SharedPortVCVlanCreateInput
from equinix.services.metalv1.models.vlan_csp_connection_create_input import VlanCSPConnectionCreateInput
from equinix.services.metalv1.models.vlan_fabric_vc_create_input import VlanFabricVcCreateInput
from equinix.services.metalv1.models.vrf_fabric_vc_create_input import VrfFabricVcCreateInput
from pydantic import StrictStr, Field
from typing import Union, List, Optional, Dict
from typing_extensions import Literal, Self

CREATEORGANIZATIONINTERCONNECTIONREQUEST_ONE_OF_SCHEMAS = ["DedicatedPortCreateInput", "SharedPortVCVlanCreateInput", "VlanCSPConnectionCreateInput", "VlanFabricVcCreateInput", "VrfFabricVcCreateInput"]

class CreateOrganizationInterconnectionRequest(BaseModel):
    """
    CreateOrganizationInterconnectionRequest
    """
    # data type: DedicatedPortCreateInput
    oneof_schema_1_validator: Optional[DedicatedPortCreateInput] = None
    # data type: VlanFabricVcCreateInput
    oneof_schema_2_validator: Optional[VlanFabricVcCreateInput] = None
    # data type: VrfFabricVcCreateInput
    oneof_schema_3_validator: Optional[VrfFabricVcCreateInput] = None
    # data type: SharedPortVCVlanCreateInput
    oneof_schema_4_validator: Optional[SharedPortVCVlanCreateInput] = None
    # data type: VlanCSPConnectionCreateInput
    oneof_schema_5_validator: Optional[VlanCSPConnectionCreateInput] = None
    actual_instance: Optional[Union[DedicatedPortCreateInput, SharedPortVCVlanCreateInput, VlanCSPConnectionCreateInput, VlanFabricVcCreateInput, VrfFabricVcCreateInput]] = None
    one_of_schemas: List[str] = Field(default=Literal["DedicatedPortCreateInput", "SharedPortVCVlanCreateInput", "VlanCSPConnectionCreateInput", "VlanFabricVcCreateInput", "VrfFabricVcCreateInput"])

    model_config = ConfigDict(
        validate_assignment=True,
        protected_namespaces=(),
    )


    def __init__(self, *args, **kwargs) -> None:
        if args:
            if len(args) > 1:
                raise ValueError("If a position argument is used, only 1 is allowed to set `actual_instance`")
            if kwargs:
                raise ValueError("If a position argument is used, keyword arguments cannot be used.")
            super().__init__(actual_instance=args[0])
        else:
            super().__init__(**kwargs)

    @field_validator('actual_instance')
    def actual_instance_must_validate_oneof(cls, v):
        instance = CreateOrganizationInterconnectionRequest.model_construct()
        error_messages = []
        match = 0
        # validate data type: DedicatedPortCreateInput
        if not isinstance(v, DedicatedPortCreateInput):
            error_messages.append(f"Error! Input type `{type(v)}` is not `DedicatedPortCreateInput`")
        else:
            match += 1
        # validate data type: VlanFabricVcCreateInput
        if not isinstance(v, VlanFabricVcCreateInput):
            error_messages.append(f"Error! Input type `{type(v)}` is not `VlanFabricVcCreateInput`")
        else:
            match += 1
        # validate data type: VrfFabricVcCreateInput
        if not isinstance(v, VrfFabricVcCreateInput):
            error_messages.append(f"Error! Input type `{type(v)}` is not `VrfFabricVcCreateInput`")
        else:
            match += 1
        # validate data type: SharedPortVCVlanCreateInput
        if not isinstance(v, SharedPortVCVlanCreateInput):
            error_messages.append(f"Error! Input type `{type(v)}` is not `SharedPortVCVlanCreateInput`")
        else:
            match += 1
        # validate data type: VlanCSPConnectionCreateInput
        if not isinstance(v, VlanCSPConnectionCreateInput):
            error_messages.append(f"Error! Input type `{type(v)}` is not `VlanCSPConnectionCreateInput`")
        else:
            match += 1
        if match > 1:
            # more than 1 match
            raise ValueError("Multiple matches found when setting `actual_instance` in CreateOrganizationInterconnectionRequest with oneOf schemas: DedicatedPortCreateInput, SharedPortVCVlanCreateInput, VlanCSPConnectionCreateInput, VlanFabricVcCreateInput, VrfFabricVcCreateInput. Details: " + ", ".join(error_messages))
        elif match == 0:
            # no match
            raise ValueError("No match found when setting `actual_instance` in CreateOrganizationInterconnectionRequest with oneOf schemas: DedicatedPortCreateInput, SharedPortVCVlanCreateInput, VlanCSPConnectionCreateInput, VlanFabricVcCreateInput, VrfFabricVcCreateInput. Details: " + ", ".join(error_messages))
        else:
            return v

    @classmethod
    def from_dict(cls, obj: Union[str, Dict[str, Any]]) -> Self:
        return cls.from_json(json.dumps(obj))

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Returns the object represented by the json string"""
        instance = cls.model_construct()
        error_messages = []
        match = 0

        # deserialize data into DedicatedPortCreateInput
        try:
            instance.actual_instance = DedicatedPortCreateInput.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into VlanFabricVcCreateInput
        try:
            instance.actual_instance = VlanFabricVcCreateInput.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into VrfFabricVcCreateInput
        try:
            instance.actual_instance = VrfFabricVcCreateInput.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into SharedPortVCVlanCreateInput
        try:
            instance.actual_instance = SharedPortVCVlanCreateInput.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into VlanCSPConnectionCreateInput
        try:
            instance.actual_instance = VlanCSPConnectionCreateInput.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))

        if match > 1:
            # more than 1 match
            raise ValueError("Multiple matches found when deserializing the JSON string into CreateOrganizationInterconnectionRequest with oneOf schemas: DedicatedPortCreateInput, SharedPortVCVlanCreateInput, VlanCSPConnectionCreateInput, VlanFabricVcCreateInput, VrfFabricVcCreateInput. Details: " + ", ".join(error_messages))
        elif match == 0:
            # no match
            raise ValueError("No match found when deserializing the JSON string into CreateOrganizationInterconnectionRequest with oneOf schemas: DedicatedPortCreateInput, SharedPortVCVlanCreateInput, VlanCSPConnectionCreateInput, VlanFabricVcCreateInput, VrfFabricVcCreateInput. Details: " + ", ".join(error_messages))
        else:
            return instance

    def to_json(self) -> str:
        """Returns the JSON representation of the actual instance"""
        if self.actual_instance is None:
            return "null"

        if hasattr(self.actual_instance, "to_json") and callable(self.actual_instance.to_json):
            return self.actual_instance.to_json()
        else:
            return json.dumps(self.actual_instance)

    def to_dict(self) -> Optional[Union[Dict[str, Any], DedicatedPortCreateInput, SharedPortVCVlanCreateInput, VlanCSPConnectionCreateInput, VlanFabricVcCreateInput, VrfFabricVcCreateInput]]:
        """Returns the dict representation of the actual instance"""
        if self.actual_instance is None:
            return None

        if hasattr(self.actual_instance, "to_dict") and callable(self.actual_instance.to_dict):
            return self.actual_instance.to_dict()
        else:
            # primitive type
            return self.actual_instance

    def to_str(self) -> str:
        """Returns the string representation of the actual instance"""
        return pprint.pformat(self.model_dump())





# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.firmware_set import FirmwareSet

class TestFirmwareSet(unittest.TestCase):
    """FirmwareSet unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FirmwareSet:
        """Test FirmwareSet
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FirmwareSet`
        """
        model = FirmwareSet()
        if include_optional:
            return FirmwareSet(
                attributes = [
                    equinix.services.metalv1.models.attribute.Attribute(
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        data = equinix.services.metalv1.models.attribute_data.AttributeData(
                            href = '', 
                            latest = True, 
                            model = '', 
                            plan = '', 
                            vendor = '', ), 
                        href = '', 
                        namespace = '', 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                component_firmware = [
                    equinix.services.metalv1.models.component.Component(
                        checksum = '', 
                        component = 'bmc', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        filename = '', 
                        href = '', 
                        model = [
                            'romed8hm3'
                            ], 
                        repository_url = '', 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        upstream_url = '', 
                        uuid = '0516463a-47ee-4809-9a66-ece8c740eed9', 
                        vendor = 'equinix', 
                        version = '1.5.0', )
                    ],
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                href = '',
                name = '',
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                uuid = '0516463a-47ee-4809-9a66-ece8c740eed9'
            )
        else:
            return FirmwareSet(
                name = '',
                uuid = '0516463a-47ee-4809-9a66-ece8c740eed9',
        )
        """

    def testFirmwareSet(self):
        """Test FirmwareSet"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from equinix.services.metalv1.models.bgp_session import BgpSession
from equinix.services.metalv1.models.global_bgp_range import GlobalBgpRange
from equinix.services.metalv1.models.href import Href
from typing import Optional, Set
from typing_extensions import Self

class BgpConfig(BaseModel):
    """
    BgpConfig
    """ # noqa: E501
    asn: Optional[Annotated[int, Field(le=4294967295, strict=True, ge=0)]] = Field(default=None, description="Autonomous System Number. ASN is required with Global BGP. With Local BGP the private ASN, 65000, is assigned.")
    created_at: Optional[datetime] = None
    deployment_type: Optional[StrictStr] = Field(default=None, description="In a Local BGP deployment, a customer uses an internal ASN to control routes within a single Equinix Metal datacenter. This means that the routes are never advertised to the global Internet. Global BGP, on the other hand, requires a customer to have a registered ASN and IP space. ")
    href: Optional[StrictStr] = None
    id: Optional[StrictStr] = None
    max_prefix: Optional[StrictInt] = Field(default=10, description="The maximum number of route filters allowed per server")
    md5: Optional[StrictStr] = Field(default=None, description="(Optional) Password for BGP session in plaintext (not a checksum)")
    project: Optional[Href] = None
    ranges: Optional[List[GlobalBgpRange]] = Field(default=None, description="The IP block ranges associated to the ASN (Populated in Global BGP only)")
    requested_at: Optional[datetime] = None
    route_object: Optional[StrictStr] = Field(default=None, description="Specifies AS-MACRO (aka AS-SET) to use when building client route filters")
    sessions: Optional[List[BgpSession]] = Field(default=None, description="The direct connections between neighboring routers that want to exchange routing information.")
    status: Optional[StrictStr] = Field(default=None, description="Status of the BGP Config. Status \"requested\" is valid only with the \"global\" deployment_type.")
    __properties: ClassVar[List[str]] = ["asn", "created_at", "deployment_type", "href", "id", "max_prefix", "md5", "project", "ranges", "requested_at", "route_object", "sessions", "status"]

    @field_validator('deployment_type')
    def deployment_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['global', 'local']):
            raise ValueError("must be one of enum values ('global', 'local')")
        return value

    @field_validator('status')
    def status_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['requested', 'enabled', 'disabled']):
            raise ValueError("must be one of enum values ('requested', 'enabled', 'disabled')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of BgpConfig from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of project
        if self.project:
            _dict['project'] = self.project.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in ranges (list)
        _items = []
        if self.ranges:
            for _item in self.ranges:
                if _item:
                    _items.append(_item.to_dict())
            _dict['ranges'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in sessions (list)
        _items = []
        if self.sessions:
            for _item in self.sessions:
                if _item:
                    _items.append(_item.to_dict())
            _dict['sessions'] = _items
        # set to None if md5 (nullable) is None
        # and model_fields_set contains the field
        if self.md5 is None and "md5" in self.model_fields_set:
            _dict['md5'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of BgpConfig from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "asn": obj.get("asn"),
            "created_at": obj.get("created_at"),
            "deployment_type": obj.get("deployment_type"),
            "href": obj.get("href"),
            "id": obj.get("id"),
            "max_prefix": obj.get("max_prefix") if obj.get("max_prefix") is not None else 10,
            "md5": obj.get("md5"),
            "project": Href.from_dict(obj["project"]) if obj.get("project") is not None else None,
            "ranges": [GlobalBgpRange.from_dict(_item) for _item in obj["ranges"]] if obj.get("ranges") is not None else None,
            "requested_at": obj.get("requested_at"),
            "route_object": obj.get("route_object"),
            "sessions": [BgpSession.from_dict(_item) for _item in obj["sessions"]] if obj.get("sessions") is not None else None,
            "status": obj.get("status")
        })
        return _obj





# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.organization_list import OrganizationList

class TestOrganizationList(unittest.TestCase):
    """OrganizationList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OrganizationList:
        """Test OrganizationList
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OrganizationList`
        """
        model = OrganizationList()
        if include_optional:
            return OrganizationList(
                href = '',
                meta = equinix.services.metalv1.models.meta.Meta(
                    current_page = 56, 
                    first = equinix.services.metalv1.models.href.Href(
                        href = '', ), 
                    href = '', 
                    last = equinix.services.metalv1.models.href.Href(
                        href = '', ), 
                    last_page = 56, 
                    next = , 
                    previous = , 
                    self = , 
                    total = 56, ),
                organizations = [
                    equinix.services.metalv1.models.organization.Organization(
                        address = equinix.services.metalv1.models.address.Address(
                            address2 = '', 
                            city = '', 
                            coordinates = equinix.services.metalv1.models.coordinates.Coordinates(
                                href = '', 
                                latitude = '', 
                                longitude = '', ), 
                            country = '', 
                            href = '', 
                            state = '', 
                            zip_code = '', ), 
                        billing_address = equinix.services.metalv1.models.address.Address(
                            address2 = '', 
                            city = '', 
                            country = '', 
                            href = '', 
                            state = '', 
                            zip_code = '', ), 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        credit_amount = 1.337, 
                        customdata = equinix.services.metalv1.models.customdata.customdata(), 
                        description = '', 
                        enforce_2fa_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        href = '', 
                        id = '', 
                        logo = '', 
                        members = [
                            equinix.services.metalv1.models.href.Href(
                                href = '', )
                            ], 
                        memberships = [
                            equinix.services.metalv1.models.href.Href(
                                href = '', )
                            ], 
                        name = '', 
                        projects = [
                            
                            ], 
                        terms = 56, 
                        twitter = '', 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        website = '', )
                    ]
            )
        else:
            return OrganizationList(
        )
        """

    def testOrganizationList(self):
        """Test OrganizationList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
